# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
IntAna module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_intana.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _IntAna
else:
    import _IntAna

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _IntAna.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _IntAna.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _IntAna.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _IntAna.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _IntAna.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _IntAna.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _IntAna.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _IntAna.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _IntAna.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _IntAna.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _IntAna.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _IntAna.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _IntAna.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _IntAna.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _IntAna.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _IntAna.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _IntAna.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _IntAna:
_IntAna.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _IntAna.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection

from enum import IntEnum
from OCC.Core.Exception import *

IntAna_Point = _IntAna.IntAna_Point
IntAna_Line = _IntAna.IntAna_Line
IntAna_Circle = _IntAna.IntAna_Circle
IntAna_PointAndCircle = _IntAna.IntAna_PointAndCircle
IntAna_Ellipse = _IntAna.IntAna_Ellipse
IntAna_Parabola = _IntAna.IntAna_Parabola
IntAna_Hyperbola = _IntAna.IntAna_Hyperbola
IntAna_Empty = _IntAna.IntAna_Empty
IntAna_Same = _IntAna.IntAna_Same
IntAna_NoGeometricSolution = _IntAna.IntAna_NoGeometricSolution


class IntAna_ResultType(IntEnum):
	IntAna_Point = 0
	IntAna_Line = 1
	IntAna_Circle = 2
	IntAna_PointAndCircle = 3
	IntAna_Ellipse = 4
	IntAna_Parabola = 5
	IntAna_Hyperbola = 6
	IntAna_Empty = 7
	IntAna_Same = 8
	IntAna_NoGeometricSolution = 9
IntAna_Point = IntAna_ResultType.IntAna_Point
IntAna_Line = IntAna_ResultType.IntAna_Line
IntAna_Circle = IntAna_ResultType.IntAna_Circle
IntAna_PointAndCircle = IntAna_ResultType.IntAna_PointAndCircle
IntAna_Ellipse = IntAna_ResultType.IntAna_Ellipse
IntAna_Parabola = IntAna_ResultType.IntAna_Parabola
IntAna_Hyperbola = IntAna_ResultType.IntAna_Hyperbola
IntAna_Empty = IntAna_ResultType.IntAna_Empty
IntAna_Same = IntAna_ResultType.IntAna_Same
IntAna_NoGeometricSolution = IntAna_ResultType.IntAna_NoGeometricSolution

class IntAna_ListIteratorOfListOfCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _IntAna.IntAna_ListIteratorOfListOfCurve_swiginit(self, _IntAna.new_IntAna_ListIteratorOfListOfCurve(*args))

    def More(self) -> "Standard_Boolean":
        return _IntAna.IntAna_ListIteratorOfListOfCurve_More(self)

    def Next(self) -> "void":
        return _IntAna.IntAna_ListIteratorOfListOfCurve_Next(self)

    def Value(self) -> "IntAna_Curve const &":
        return _IntAna.IntAna_ListIteratorOfListOfCurve_Value(self)

    def ChangeValue(self) -> "IntAna_Curve &":
        return _IntAna.IntAna_ListIteratorOfListOfCurve_ChangeValue(self)
    __swig_destroy__ = _IntAna.delete_IntAna_ListIteratorOfListOfCurve

# Register IntAna_ListIteratorOfListOfCurve in _IntAna:
_IntAna.IntAna_ListIteratorOfListOfCurve_swigregister(IntAna_ListIteratorOfListOfCurve)

class IntAna_ListOfCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_List< IntAna_Curve >::iterator":
        return _IntAna.IntAna_ListOfCurve_begin(self)

    def end(self) -> "NCollection_List< IntAna_Curve >::iterator":
        return _IntAna.IntAna_ListOfCurve_end(self)

    def cbegin(self) -> "NCollection_List< IntAna_Curve >::const_iterator":
        return _IntAna.IntAna_ListOfCurve_cbegin(self)

    def cend(self) -> "NCollection_List< IntAna_Curve >::const_iterator":
        return _IntAna.IntAna_ListOfCurve_cend(self)

    def __init__(self, *args):
        _IntAna.IntAna_ListOfCurve_swiginit(self, _IntAna.new_IntAna_ListOfCurve(*args))

    def Size(self) -> "Standard_Integer":
        return _IntAna.IntAna_ListOfCurve_Size(self)

    def Assign(self, theOther: "IntAna_ListOfCurve") -> "NCollection_List< IntAna_Curve > &":
        return _IntAna.IntAna_ListOfCurve_Assign(self, theOther)

    def Set(self, theOther: "IntAna_ListOfCurve") -> "NCollection_List< IntAna_Curve > &":
        return _IntAna.IntAna_ListOfCurve_Set(self, theOther)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _IntAna.IntAna_ListOfCurve_Clear(self, theAllocator)

    def First(self) -> "IntAna_Curve const &":
        return _IntAna.IntAna_ListOfCurve_First(self)

    def Last(self) -> "IntAna_Curve const &":
        return _IntAna.IntAna_ListOfCurve_Last(self)

    def Append(self, *args) -> "void":
        return _IntAna.IntAna_ListOfCurve_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _IntAna.IntAna_ListOfCurve_Prepend(self, *args)

    def RemoveFirst(self) -> "void":
        return _IntAna.IntAna_ListOfCurve_RemoveFirst(self)

    def Remove(self, theIter: "IntAna_ListIteratorOfListOfCurve") -> "void":
        return _IntAna.IntAna_ListOfCurve_Remove(self, theIter)

    def InsertBefore(self, *args) -> "void":
        return _IntAna.IntAna_ListOfCurve_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _IntAna.IntAna_ListOfCurve_InsertAfter(self, *args)

    def Reverse(self) -> "void":
        return _IntAna.IntAna_ListOfCurve_Reverse(self)
    __swig_destroy__ = _IntAna.delete_IntAna_ListOfCurve

    def __len__(self):
        return self.Size()


# Register IntAna_ListOfCurve in _IntAna:
_IntAna.IntAna_ListOfCurve_swigregister(IntAna_ListOfCurve)

class IntAna_Curve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _IntAna.IntAna_Curve_swiginit(self, _IntAna.new_IntAna_Curve(*args))

    def D1u(self, *args) -> "Standard_Boolean":
        r"""
        Returns the point and the first derivative at parameter theta on the curve.

        Parameters
        ----------
        Theta: float
        P: gp_Pnt
        V: gp_Vec

        Returns
        -------
        bool

        """
        return _IntAna.IntAna_Curve_D1u(self, *args)

    def Domain(self, *args) -> "void":
        r"""
        Returns the paramatric domain of the curve.

        Parameters
        ----------

        Returns
        -------
        theFirst: float
        theLast: float

        """
        return _IntAna.IntAna_Curve_Domain(self, *args)

    def FindParameter(self, *args) -> "void":
        r"""
        Tries to find the parameter of the point p on the curve. if the method returns false, the 'projection' is impossible. if the method returns true at least one parameter has been found. theparams is always sorted in ascending order.

        Parameters
        ----------
        P: gp_Pnt
        theParams: TColStd_ListOfReal

        Returns
        -------
        None

        """
        return _IntAna.IntAna_Curve_FindParameter(self, *args)

    def IsConstant(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the function is constant.

        Returns
        -------
        bool

        """
        return _IntAna.IntAna_Curve_IsConstant(self, *args)

    def IsFirstOpen(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the domain is open at the beginning.

        Returns
        -------
        bool

        """
        return _IntAna.IntAna_Curve_IsFirstOpen(self, *args)

    def IsLastOpen(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the domain is open at the end.

        Returns
        -------
        bool

        """
        return _IntAna.IntAna_Curve_IsLastOpen(self, *args)

    def IsOpen(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the curve is not infinite at the last parameter or at the first parameter of the domain.

        Returns
        -------
        bool

        """
        return _IntAna.IntAna_Curve_IsOpen(self, *args)

    def SetConeQuadValues(self, *args) -> "void":
        r"""
        Sets the parameters used to compute points and derivative on the curve.

        Parameters
        ----------
        Cone: gp_Cone
        Qxx: float
        Qyy: float
        Qzz: float
        Qxy: float
        Qxz: float
        Qyz: float
        Qx: float
        Qy: float
        Qz: float
        Q1: float
        Tol: float
        DomInf: float
        DomSup: float
        TwoZForATheta: bool
        ZIsPositive: bool

        Returns
        -------
        None

        """
        return _IntAna.IntAna_Curve_SetConeQuadValues(self, *args)

    def SetCylinderQuadValues(self, *args) -> "void":
        r"""
        Sets the parameters used to compute points and derivative on the curve.

        Parameters
        ----------
        Cylinder: gp_Cylinder
        Qxx: float
        Qyy: float
        Qzz: float
        Qxy: float
        Qxz: float
        Qyz: float
        Qx: float
        Qy: float
        Qz: float
        Q1: float
        Tol: float
        DomInf: float
        DomSup: float
        TwoZForATheta: bool
        ZIsPositive: bool

        Returns
        -------
        None

        """
        return _IntAna.IntAna_Curve_SetCylinderQuadValues(self, *args)

    def SetDomain(self, *args) -> "void":
        r"""
        Trims this curve.

        Parameters
        ----------
        theFirst: float
        theLast: float

        Returns
        -------
        None

        """
        return _IntAna.IntAna_Curve_SetDomain(self, *args)

    def SetIsFirstOpen(self, *args) -> "void":
        r"""
        If flag is true, the curve is not defined at the first parameter of its domain.

        Parameters
        ----------
        Flag: bool

        Returns
        -------
        None

        """
        return _IntAna.IntAna_Curve_SetIsFirstOpen(self, *args)

    def SetIsLastOpen(self, *args) -> "void":
        r"""
        If flag is true, the curve is not defined at the first parameter of its domain.

        Parameters
        ----------
        Flag: bool

        Returns
        -------
        None

        """
        return _IntAna.IntAna_Curve_SetIsLastOpen(self, *args)

    def Value(self, *args) -> "gp_Pnt":
        r"""
        Returns the point at parameter theta on the curve.

        Parameters
        ----------
        Theta: float

        Returns
        -------
        gp_Pnt

        """
        return _IntAna.IntAna_Curve_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _IntAna.delete_IntAna_Curve

# Register IntAna_Curve in _IntAna:
_IntAna.IntAna_Curve_swigregister(IntAna_Curve)

class IntAna_Int3Pln(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        Determination of the intersection point between 3 planes.

        Parameters
        ----------
        P1: gp_Pln
        P2: gp_Pln
        P3: gp_Pln

        Returns
        -------
        None

        """
        _IntAna.IntAna_Int3Pln_swiginit(self, _IntAna.new_IntAna_Int3Pln(*args))

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the computation was successful.

        Returns
        -------
        bool

        """
        return _IntAna.IntAna_Int3Pln_IsDone(self, *args)

    def IsEmpty(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if there is no intersection point. if 2 planes are identical or parallel, isempty will return true.

        Returns
        -------
        bool

        """
        return _IntAna.IntAna_Int3Pln_IsEmpty(self, *args)

    def Perform(self, *args) -> "void":
        r"""
        Determination of the intersection point between 3 planes.

        Parameters
        ----------
        P1: gp_Pln
        P2: gp_Pln
        P3: gp_Pln

        Returns
        -------
        None

        """
        return _IntAna.IntAna_Int3Pln_Perform(self, *args)

    def Value(self, *args) -> "gp_Pnt const":
        r"""
        Returns the intersection point.

        Returns
        -------
        gp_Pnt

        """
        return _IntAna.IntAna_Int3Pln_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _IntAna.delete_IntAna_Int3Pln

# Register IntAna_Int3Pln in _IntAna:
_IntAna.IntAna_Int3Pln_swigregister(IntAna_Int3Pln)

class IntAna_IntConicQuad(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None
        Creates the intersection between a line and a quadric.

        Parameters
        ----------
        L: gp_Lin
        Q: IntAna_Quadric

        Returns
        -------
        None
        Creates the intersection between a circle and a quadric.

        Parameters
        ----------
        C: gp_Circ
        Q: IntAna_Quadric

        Returns
        -------
        None
        Creates the intersection between an ellipse and a quadric.

        Parameters
        ----------
        E: gp_Elips
        Q: IntAna_Quadric

        Returns
        -------
        None
        Creates the intersection between a parabola and a quadric.

        Parameters
        ----------
        P: gp_Parab
        Q: IntAna_Quadric

        Returns
        -------
        None
        Creates the intersection between an hyperbola and a quadric.

        Parameters
        ----------
        H: gp_Hypr
        Q: IntAna_Quadric

        Returns
        -------
        None
        Intersection between a line and a plane. tolang is used to determine if the angle between two vectors is null. tol is used to check the distance between line and plane on the distance <len> from the origin of the line.

        Parameters
        ----------
        L: gp_Lin
        P: gp_Pln
        Tolang: float
        Tol: float,optional
        	default value is 0
        Len: float,optional
        	default value is 0

        Returns
        -------
        None
        Intersection between a circle and a plane. tolang is used to determine if the angle between two vectors is null. tol is used to determine if a distance is null.

        Parameters
        ----------
        C: gp_Circ
        P: gp_Pln
        Tolang: float
        Tol: float

        Returns
        -------
        None
        Intersection between an ellipse and a plane. tolang is used to determine if the angle between two vectors is null. tol is used to determine if a distance is null.

        Parameters
        ----------
        E: gp_Elips
        P: gp_Pln
        Tolang: float
        Tol: float

        Returns
        -------
        None
        Intersection between a parabola and a plane. tolang is used to determine if the angle between two vectors is null.

        Parameters
        ----------
        Pb: gp_Parab
        P: gp_Pln
        Tolang: float

        Returns
        -------
        None
        Intersection between an hyperbola and a plane. tolang is used to determine if the angle between two vectors is null.

        Parameters
        ----------
        H: gp_Hypr
        P: gp_Pln
        Tolang: float

        Returns
        -------
        None

        """
        _IntAna.IntAna_IntConicQuad_swiginit(self, _IntAna.new_IntAna_IntConicQuad(*args))

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the creation completed.

        Returns
        -------
        bool

        """
        return _IntAna.IntAna_IntConicQuad_IsDone(self, *args)

    def IsInQuadric(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the conic is in the quadric.

        Returns
        -------
        bool

        """
        return _IntAna.IntAna_IntConicQuad_IsInQuadric(self, *args)

    def IsParallel(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the line is in a quadric which is parallel to the quadric.

        Returns
        -------
        bool

        """
        return _IntAna.IntAna_IntConicQuad_IsParallel(self, *args)

    def NbPoints(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of intersection point.

        Returns
        -------
        int

        """
        return _IntAna.IntAna_IntConicQuad_NbPoints(self, *args)

    def ParamOnConic(self, *args) -> "Standard_Real":
        r"""
        Returns the parameter on the line of the intersection point of range n.

        Parameters
        ----------
        N: int

        Returns
        -------
        float

        """
        return _IntAna.IntAna_IntConicQuad_ParamOnConic(self, *args)

    def Perform(self, *args) -> "void":
        r"""
        Intersects a line and a quadric.

        Parameters
        ----------
        L: gp_Lin
        Q: IntAna_Quadric

        Returns
        -------
        None
        Intersects a circle and a quadric.

        Parameters
        ----------
        C: gp_Circ
        Q: IntAna_Quadric

        Returns
        -------
        None
        Intersects an ellipse and a quadric.

        Parameters
        ----------
        E: gp_Elips
        Q: IntAna_Quadric

        Returns
        -------
        None
        Intersects a parabola and a quadric.

        Parameters
        ----------
        P: gp_Parab
        Q: IntAna_Quadric

        Returns
        -------
        None
        Intersects an hyperbola and a quadric.

        Parameters
        ----------
        H: gp_Hypr
        Q: IntAna_Quadric

        Returns
        -------
        None
        Intersects a line and a plane. tolang is used to determine if the angle between two vectors is null. tol is used to check the distance between line and plane on the distance <len> from the origin of the line.

        Parameters
        ----------
        L: gp_Lin
        P: gp_Pln
        Tolang: float
        Tol: float,optional
        	default value is 0
        Len: float,optional
        	default value is 0

        Returns
        -------
        None
        Intersects a circle and a plane. tolang is used to determine if the angle between two vectors is null. tol is used to determine if a distance is null.

        Parameters
        ----------
        C: gp_Circ
        P: gp_Pln
        Tolang: float
        Tol: float

        Returns
        -------
        None
        Intersects an ellipse and a plane. tolang is used to determine if the angle between two vectors is null. tol is used to determine if a distance is null.

        Parameters
        ----------
        E: gp_Elips
        P: gp_Pln
        Tolang: float
        Tol: float

        Returns
        -------
        None
        Intersects a parabola and a plane. tolang is used to determine if the angle between two vectors is null.

        Parameters
        ----------
        Pb: gp_Parab
        P: gp_Pln
        Tolang: float

        Returns
        -------
        None
        Intersects an hyperbola and a plane. tolang is used to determine if the angle between two vectors is null.

        Parameters
        ----------
        H: gp_Hypr
        P: gp_Pln
        Tolang: float

        Returns
        -------
        None

        """
        return _IntAna.IntAna_IntConicQuad_Perform(self, *args)

    def Point(self, *args) -> "gp_Pnt const":
        r"""
        Returns the point of range n.

        Parameters
        ----------
        N: int

        Returns
        -------
        gp_Pnt

        """
        return _IntAna.IntAna_IntConicQuad_Point(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _IntAna.delete_IntAna_IntConicQuad

# Register IntAna_IntConicQuad in _IntAna:
_IntAna.IntAna_IntConicQuad_swigregister(IntAna_IntConicQuad)

class IntAna_IntLinTorus(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        Creates the intersection between a line and a torus.

        Parameters
        ----------
        L: gp_Lin
        T: gp_Torus

        Returns
        -------
        None

        """
        _IntAna.IntAna_IntLinTorus_swiginit(self, _IntAna.new_IntAna_IntLinTorus(*args))

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the computation was successful.

        Returns
        -------
        bool

        """
        return _IntAna.IntAna_IntLinTorus_IsDone(self, *args)

    def NbPoints(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of intersection points.

        Returns
        -------
        int

        """
        return _IntAna.IntAna_IntLinTorus_NbPoints(self, *args)

    def ParamOnLine(self, *args) -> "Standard_Real":
        r"""
        Returns the parameter on the line of the intersection point of range index.

        Parameters
        ----------
        Index: int

        Returns
        -------
        float

        """
        return _IntAna.IntAna_IntLinTorus_ParamOnLine(self, *args)

    def ParamOnTorus(self, *args) -> "void":
        r"""
        Returns the parameters on the torus of the intersection point of range index.

        Parameters
        ----------
        Index: int

        Returns
        -------
        FI: float
        THETA: float

        """
        return _IntAna.IntAna_IntLinTorus_ParamOnTorus(self, *args)

    def Perform(self, *args) -> "void":
        r"""
        Intersects a line and a torus.

        Parameters
        ----------
        L: gp_Lin
        T: gp_Torus

        Returns
        -------
        None

        """
        return _IntAna.IntAna_IntLinTorus_Perform(self, *args)

    def Value(self, *args) -> "gp_Pnt const":
        r"""
        Returns the intersection point of range index.

        Parameters
        ----------
        Index: int

        Returns
        -------
        gp_Pnt

        """
        return _IntAna.IntAna_IntLinTorus_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _IntAna.delete_IntAna_IntLinTorus

# Register IntAna_IntLinTorus in _IntAna:
_IntAna.IntAna_IntLinTorus_swigregister(IntAna_IntLinTorus)

class IntAna_IntQuadQuad(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None
        Creates the intersection between a cylinder and a quadric . tol est a definir plus precisemment.

        Parameters
        ----------
        C: gp_Cylinder
        Q: IntAna_Quadric
        Tol: float

        Returns
        -------
        None
        Creates the intersection between a cone and a quadric. tol est a definir plus precisemment.

        Parameters
        ----------
        C: gp_Cone
        Q: IntAna_Quadric
        Tol: float

        Returns
        -------
        None

        """
        _IntAna.IntAna_IntQuadQuad_swiginit(self, _IntAna.new_IntAna_IntQuadQuad(*args))

    def Curve(self, *args) -> "IntAna_Curve const &":
        r"""
        Returns the curve of range n.

        Parameters
        ----------
        N: int

        Returns
        -------
        IntAna_Curve

        """
        return _IntAna.IntAna_IntQuadQuad_Curve(self, *args)

    def HasNextCurve(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the curve i shares its last bound with another curve.

        Parameters
        ----------
        I: int

        Returns
        -------
        bool

        """
        return _IntAna.IntAna_IntQuadQuad_HasNextCurve(self, *args)

    def HasPreviousCurve(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the curve i shares its first bound with another curve.

        Parameters
        ----------
        I: int

        Returns
        -------
        bool

        """
        return _IntAna.IntAna_IntQuadQuad_HasPreviousCurve(self, *args)

    def IdenticalElements(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the cylinder, the cone or the sphere is identical to the quadric.

        Returns
        -------
        bool

        """
        return _IntAna.IntAna_IntQuadQuad_IdenticalElements(self, *args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the computation was successful.

        Returns
        -------
        bool

        """
        return _IntAna.IntAna_IntQuadQuad_IsDone(self, *args)

    def NbCurve(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of curves solution.

        Returns
        -------
        int

        """
        return _IntAna.IntAna_IntQuadQuad_NbCurve(self, *args)

    def NbPnt(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of contact point.

        Returns
        -------
        int

        """
        return _IntAna.IntAna_IntQuadQuad_NbPnt(self, *args)

    def NextCurve(self, *args) -> "Standard_Integer":
        r"""
        If hasnextcurve(i) returns true, this function returns the index j of the curve which has a common bound with the curve i. if theopposite == true , then the last parameter of the curve i, and the last parameter of the curve j give the same point. else the last parameter of the curve i and the first parameter of the curve j are the same point.

        Parameters
        ----------
        I: int

        Returns
        -------
        theOpposite: bool

        """
        return _IntAna.IntAna_IntQuadQuad_NextCurve(self, *args)

    def Parameters(self, *args) -> "void":
        r"""
        Returns the paramaters on the 'explicit quadric' (i.e the cylinder or the cone, the first argument given to the constructor) of the point of range n.

        Parameters
        ----------
        N: int

        Returns
        -------
        U1: float
        U2: float

        """
        return _IntAna.IntAna_IntQuadQuad_Parameters(self, *args)

    def Perform(self, *args) -> "void":
        r"""
        Intersects a cylinder and a quadric . tol est a definir plus precisemment.

        Parameters
        ----------
        C: gp_Cylinder
        Q: IntAna_Quadric
        Tol: float

        Returns
        -------
        None
        Intersects a cone and a quadric. tol est a definir plus precisemment.

        Parameters
        ----------
        C: gp_Cone
        Q: IntAna_Quadric
        Tol: float

        Returns
        -------
        None

        """
        return _IntAna.IntAna_IntQuadQuad_Perform(self, *args)

    def Point(self, *args) -> "gp_Pnt const":
        r"""
        Returns the point of range n.

        Parameters
        ----------
        N: int

        Returns
        -------
        gp_Pnt

        """
        return _IntAna.IntAna_IntQuadQuad_Point(self, *args)

    def PreviousCurve(self, *args) -> "Standard_Integer":
        r"""
        If haspreviouscurve(i) returns true, this function returns the index j of the curve which has a common bound with the curve i. if theopposite == true , then the first parameter of the curve i, and the first parameter of the curve j give the same point. else the first parameter of the curve i and the last parameter of the curve j are the same point.

        Parameters
        ----------
        I: int

        Returns
        -------
        theOpposite: bool

        """
        return _IntAna.IntAna_IntQuadQuad_PreviousCurve(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _IntAna.delete_IntAna_IntQuadQuad

# Register IntAna_IntQuadQuad in _IntAna:
_IntAna.IntAna_IntQuadQuad_swigregister(IntAna_IntQuadQuad)

class IntAna_QuadQuadGeo(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None
        Creates the intersection between two planes. tolang is the angular tolerance used to determine if the planes are parallel. tol is the tolerance used to determine if the planes are identical (only when they are parallel).

        Parameters
        ----------
        P1: gp_Pln
        P2: gp_Pln
        TolAng: float
        Tol: float

        Returns
        -------
        None
        Creates the intersection between a plane and a cylinder. tolang is the angular tolerance used to determine if the axis of the cylinder is parallel to the plane. tol is the tolerance used to determine if the result is a circle or an ellipse. if the maximum distance between the ellipse solution and the circle centered at the ellipse center is less than tol, the result will be the circle. h is the height of the cylinder <cyl>. it is used to check whether the plane and cylinder are parallel.

        Parameters
        ----------
        P: gp_Pln
        C: gp_Cylinder
        Tolang: float
        Tol: float
        H: float,optional
        	default value is 0

        Returns
        -------
        None
        Creates the intersection between a plane and a sphere.

        Parameters
        ----------
        P: gp_Pln
        S: gp_Sphere

        Returns
        -------
        None
        Creates the intersection between a plane and a cone. tolang is the angular tolerance used to determine if the axis of the cone is parallel or perpendicular to the plane, and if the generating line of the cone is parallel to the plane. tol is the tolerance used to determine if the apex of the cone is in the plane.

        Parameters
        ----------
        P: gp_Pln
        C: gp_Cone
        Tolang: float
        Tol: float

        Returns
        -------
        None
        Creates the intersection between two cylinders.

        Parameters
        ----------
        Cyl1: gp_Cylinder
        Cyl2: gp_Cylinder
        Tol: float

        Returns
        -------
        None
        Creates the intersection between a cylinder and a sphere.

        Parameters
        ----------
        Cyl: gp_Cylinder
        Sph: gp_Sphere
        Tol: float

        Returns
        -------
        None
        Creates the intersection between a cylinder and a cone.

        Parameters
        ----------
        Cyl: gp_Cylinder
        Con: gp_Cone
        Tol: float

        Returns
        -------
        None
        Creates the intersection between two spheres.

        Parameters
        ----------
        Sph1: gp_Sphere
        Sph2: gp_Sphere
        Tol: float

        Returns
        -------
        None
        Creates the intersection beween a sphere and a cone.

        Parameters
        ----------
        Sph: gp_Sphere
        Con: gp_Cone
        Tol: float

        Returns
        -------
        None
        Creates the intersection beween two cones.

        Parameters
        ----------
        Con1: gp_Cone
        Con2: gp_Cone
        Tol: float

        Returns
        -------
        None
        Creates the intersection beween plane and torus.

        Parameters
        ----------
        Pln: gp_Pln
        Tor: gp_Torus
        Tol: float

        Returns
        -------
        None
        Creates the intersection beween cylinder and torus.

        Parameters
        ----------
        Cyl: gp_Cylinder
        Tor: gp_Torus
        Tol: float

        Returns
        -------
        None
        Creates the intersection beween cone and torus.

        Parameters
        ----------
        Con: gp_Cone
        Tor: gp_Torus
        Tol: float

        Returns
        -------
        None
        Creates the intersection beween sphere and torus.

        Parameters
        ----------
        Sph: gp_Sphere
        Tor: gp_Torus
        Tol: float

        Returns
        -------
        None
        Creates the intersection beween two toruses.

        Parameters
        ----------
        Tor1: gp_Torus
        Tor2: gp_Torus
        Tol: float

        Returns
        -------
        None

        """
        _IntAna.IntAna_QuadQuadGeo_swiginit(self, _IntAna.new_IntAna_QuadQuadGeo(*args))

    def Circle(self, *args) -> "gp_Circ":
        r"""
        Returns the circle solution of range num.

        Parameters
        ----------
        Num: int

        Returns
        -------
        gp_Circ

        """
        return _IntAna.IntAna_QuadQuadGeo_Circle(self, *args)

    def Ellipse(self, *args) -> "gp_Elips":
        r"""
        Returns the ellipse solution of range num.

        Parameters
        ----------
        Num: int

        Returns
        -------
        gp_Elips

        """
        return _IntAna.IntAna_QuadQuadGeo_Ellipse(self, *args)

    def HasCommonGen(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _IntAna.IntAna_QuadQuadGeo_HasCommonGen(self, *args)

    def Hyperbola(self, *args) -> "gp_Hypr":
        r"""
        Returns the hyperbola solution of range num.

        Parameters
        ----------
        Num: int

        Returns
        -------
        gp_Hypr

        """
        return _IntAna.IntAna_QuadQuadGeo_Hyperbola(self, *args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns standard_true if the computation was successful.

        Returns
        -------
        bool

        """
        return _IntAna.IntAna_QuadQuadGeo_IsDone(self, *args)

    def Line(self, *args) -> "gp_Lin":
        r"""
        Returns the line solution of range num.

        Parameters
        ----------
        Num: int

        Returns
        -------
        gp_Lin

        """
        return _IntAna.IntAna_QuadQuadGeo_Line(self, *args)

    def NbSolutions(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of interesections. the possible intersections are : - 1 point - 1 or 2 line(s) - 1 point and 1 line - 1 circle - 1 ellipse - 1 parabola - 1 or 2 hyperbola(s).

        Returns
        -------
        int

        """
        return _IntAna.IntAna_QuadQuadGeo_NbSolutions(self, *args)

    def PChar(self, *args) -> "gp_Pnt const":
        r"""
        No available documentation.

        Returns
        -------
        gp_Pnt

        """
        return _IntAna.IntAna_QuadQuadGeo_PChar(self, *args)

    def Parabola(self, *args) -> "gp_Parab":
        r"""
        Returns the parabola solution of range num.

        Parameters
        ----------
        Num: int

        Returns
        -------
        gp_Parab

        """
        return _IntAna.IntAna_QuadQuadGeo_Parabola(self, *args)

    def Perform(self, *args) -> "void":
        r"""
        Intersects two planes. tolang is the angular tolerance used to determine if the planes are parallel. tol is the tolerance used to determine if the planes are identical (only when they are parallel).

        Parameters
        ----------
        P1: gp_Pln
        P2: gp_Pln
        TolAng: float
        Tol: float

        Returns
        -------
        None
        Intersects a plane and a cylinder. tolang is the angular tolerance used to determine if the axis of the cylinder is parallel to the plane. tol is the tolerance used to determine if the result is a circle or an ellipse. if the maximum distance between the ellipse solution and the circle centered at the ellipse center is less than tol, the result will be the circle. h is the height of the cylinder <cyl>. it is used to check whether the plane and cylinder are parallel.

        Parameters
        ----------
        P: gp_Pln
        C: gp_Cylinder
        Tolang: float
        Tol: float
        H: float,optional
        	default value is 0

        Returns
        -------
        None
        Intersects a plane and a sphere.

        Parameters
        ----------
        P: gp_Pln
        S: gp_Sphere

        Returns
        -------
        None
        Intersects a plane and a cone. tolang is the angular tolerance used to determine if the axis of the cone is parallel or perpendicular to the plane, and if the generating line of the cone is parallel to the plane. tol is the tolerance used to determine if the apex of the cone is in the plane.

        Parameters
        ----------
        P: gp_Pln
        C: gp_Cone
        Tolang: float
        Tol: float

        Returns
        -------
        None
        Intersects two cylinders.

        Parameters
        ----------
        Cyl1: gp_Cylinder
        Cyl2: gp_Cylinder
        Tol: float

        Returns
        -------
        None
        Intersects a cylinder and a sphere.

        Parameters
        ----------
        Cyl: gp_Cylinder
        Sph: gp_Sphere
        Tol: float

        Returns
        -------
        None
        Intersects a cylinder and a cone.

        Parameters
        ----------
        Cyl: gp_Cylinder
        Con: gp_Cone
        Tol: float

        Returns
        -------
        None
        Intersects a two spheres.

        Parameters
        ----------
        Sph1: gp_Sphere
        Sph2: gp_Sphere
        Tol: float

        Returns
        -------
        None
        Intersects a sphere and a cone.

        Parameters
        ----------
        Sph: gp_Sphere
        Con: gp_Cone
        Tol: float

        Returns
        -------
        None
        Intersects two cones.

        Parameters
        ----------
        Con1: gp_Cone
        Con2: gp_Cone
        Tol: float

        Returns
        -------
        None
        Intersects plane and torus.

        Parameters
        ----------
        Pln: gp_Pln
        Tor: gp_Torus
        Tol: float

        Returns
        -------
        None
        Intersects cylinder and torus.

        Parameters
        ----------
        Cyl: gp_Cylinder
        Tor: gp_Torus
        Tol: float

        Returns
        -------
        None
        Intersects cone and torus.

        Parameters
        ----------
        Con: gp_Cone
        Tor: gp_Torus
        Tol: float

        Returns
        -------
        None
        Intersects sphere and torus.

        Parameters
        ----------
        Sph: gp_Sphere
        Tor: gp_Torus
        Tol: float

        Returns
        -------
        None
        Intersects two toruses.

        Parameters
        ----------
        Tor1: gp_Torus
        Tor2: gp_Torus
        Tol: float

        Returns
        -------
        None

        """
        return _IntAna.IntAna_QuadQuadGeo_Perform(self, *args)

    def Point(self, *args) -> "gp_Pnt":
        r"""
        Returns the point solution of range num.

        Parameters
        ----------
        Num: int

        Returns
        -------
        gp_Pnt

        """
        return _IntAna.IntAna_QuadQuadGeo_Point(self, *args)

    def TypeInter(self, *args) -> "IntAna_ResultType":
        r"""
        Returns the type of intersection.

        Returns
        -------
        IntAna_ResultType

        """
        return _IntAna.IntAna_QuadQuadGeo_TypeInter(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _IntAna.delete_IntAna_QuadQuadGeo

# Register IntAna_QuadQuadGeo in _IntAna:
_IntAna.IntAna_QuadQuadGeo_swigregister(IntAna_QuadQuadGeo)

class IntAna_Quadric(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None
        Creates a quadric from a pln.

        Parameters
        ----------
        P: gp_Pln

        Returns
        -------
        None
        Creates a quadric from a sphere.

        Parameters
        ----------
        Sph: gp_Sphere

        Returns
        -------
        None
        Creates a quadric from a cylinder.

        Parameters
        ----------
        Cyl: gp_Cylinder

        Returns
        -------
        None
        Creates a quadric from a cone.

        Parameters
        ----------
        Cone: gp_Cone

        Returns
        -------
        None

        """
        _IntAna.IntAna_Quadric_swiginit(self, _IntAna.new_IntAna_Quadric(*args))

    def Coefficients(self, *args) -> "void":
        r"""
        Returns the coefficients of the polynomial equation which define the quadric: xcxx x**2 + xcyy y**2 + xczz z**2 + 2 ( xcxy x y + xcxz x z + xcyz y z ) + 2 ( xcx x + xcy y + xcz z ) + xccte.

        Parameters
        ----------

        Returns
        -------
        xCXX: float
        xCYY: float
        xCZZ: float
        xCXY: float
        xCXZ: float
        xCYZ: float
        xCX: float
        xCY: float
        xCZ: float
        xCCte: float

        """
        return _IntAna.IntAna_Quadric_Coefficients(self, *args)

    def NewCoefficients(self, *args) -> "void":
        r"""
        Returns the coefficients of the polynomial equation ( written in the natural coordinates system ) in the local coordinates system defined by axis.

        Parameters
        ----------
        Axis: gp_Ax3

        Returns
        -------
        xCXX: float
        xCYY: float
        xCZZ: float
        xCXY: float
        xCXZ: float
        xCYZ: float
        xCX: float
        xCY: float
        xCZ: float
        xCCte: float

        """
        return _IntAna.IntAna_Quadric_NewCoefficients(self, *args)

    def SetQuadric(self, *args) -> "void":
        r"""
        Initializes the quadric with a pln.

        Parameters
        ----------
        P: gp_Pln

        Returns
        -------
        None
        Initialize the quadric with a sphere.

        Parameters
        ----------
        Sph: gp_Sphere

        Returns
        -------
        None
        Initializes the quadric with a cone.

        Parameters
        ----------
        Con: gp_Cone

        Returns
        -------
        None
        Initializes the quadric with a cylinder.

        Parameters
        ----------
        Cyl: gp_Cylinder

        Returns
        -------
        None

        """
        return _IntAna.IntAna_Quadric_SetQuadric(self, *args)

    def SpecialPoints(self, *args) -> "NCollection_List< gp_Pnt > const":
        r"""
        Returns the list of special points (with singularities).

        Returns
        -------
        NCollection_List<gp_Pnt>

        """
        return _IntAna.IntAna_Quadric_SpecialPoints(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _IntAna.delete_IntAna_Quadric

# Register IntAna_Quadric in _IntAna:
_IntAna.IntAna_Quadric_swigregister(IntAna_Quadric)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Adaptor3d import *
from OCC.Core.Adaptor2d import *
from OCC.Core.math import *
from OCC.Core.GeomAbs import *
from OCC.Core.gp import *


class GCPnts_DeflectionType(IntEnum):
	GCPnts_Linear: int = ...
	GCPnts_Circular: int = ...
	GCPnts_Curved: int = ...
	GCPnts_DefComposite: int = ...
GCPnts_Linear = GCPnts_DeflectionType.GCPnts_Linear
GCPnts_Circular = GCPnts_DeflectionType.GCPnts_Circular
GCPnts_Curved = GCPnts_DeflectionType.GCPnts_Curved
GCPnts_DefComposite = GCPnts_DeflectionType.GCPnts_DefComposite

class GCPnts_AbscissaType(IntEnum):
	GCPnts_LengthParametrized: int = ...
	GCPnts_Parametrized: int = ...
	GCPnts_AbsComposite: int = ...
GCPnts_LengthParametrized = GCPnts_AbscissaType.GCPnts_LengthParametrized
GCPnts_Parametrized = GCPnts_AbscissaType.GCPnts_Parametrized
GCPnts_AbsComposite = GCPnts_AbscissaType.GCPnts_AbsComposite

class GCPnts_AbscissaPoint:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, C: Adaptor3d_Curve, Abscissa: float, U0: float) -> None: ...
	@overload
	def __init__(self, Tol: float, C: Adaptor3d_Curve, Abscissa: float, U0: float) -> None: ...
	@overload
	def __init__(self, Tol: float, C: Adaptor2d_Curve2d, Abscissa: float, U0: float) -> None: ...
	@overload
	def __init__(self, C: Adaptor2d_Curve2d, Abscissa: float, U0: float) -> None: ...
	@overload
	def __init__(self, C: Adaptor3d_Curve, Abscissa: float, U0: float, Ui: float) -> None: ...
	@overload
	def __init__(self, C: Adaptor2d_Curve2d, Abscissa: float, U0: float, Ui: float) -> None: ...
	@overload
	def __init__(self, C: Adaptor3d_Curve, Abscissa: float, U0: float, Ui: float, Tol: float) -> None: ...
	@overload
	def __init__(self, C: Adaptor2d_Curve2d, Abscissa: float, U0: float, Ui: float, Tol: float) -> None: ...
	def IsDone(self) -> bool: ...
	@overload
	@staticmethod
	def Length(C: Adaptor3d_Curve) -> float: ...
	@overload
	@staticmethod
	def Length(C: Adaptor2d_Curve2d) -> float: ...
	@overload
	@staticmethod
	def Length(C: Adaptor3d_Curve, Tol: float) -> float: ...
	@overload
	@staticmethod
	def Length(C: Adaptor2d_Curve2d, Tol: float) -> float: ...
	@overload
	@staticmethod
	def Length(C: Adaptor3d_Curve, U1: float, U2: float) -> float: ...
	@overload
	@staticmethod
	def Length(C: Adaptor2d_Curve2d, U1: float, U2: float) -> float: ...
	@overload
	@staticmethod
	def Length(C: Adaptor3d_Curve, U1: float, U2: float, Tol: float) -> float: ...
	@overload
	@staticmethod
	def Length(C: Adaptor2d_Curve2d, U1: float, U2: float, Tol: float) -> float: ...
	def Parameter(self) -> float: ...

class GCPnts_DistFunction2dMV(math_MultipleVarFunction):
	def __init__(self, theCurvLinDist: GCPnts_DistFunction2d) -> None: ...
	def NbVariables(self) -> int: ...
	def Value(self, X: math_Vector) -> Tuple[bool, float]: ...

class GCPnts_DistFunctionMV(math_MultipleVarFunction):
	def __init__(self, theCurvLinDist: GCPnts_DistFunction) -> None: ...
	def NbVariables(self) -> int: ...
	def Value(self, X: math_Vector) -> Tuple[bool, float]: ...

class GCPnts_QuasiUniformAbscissa:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, C: Adaptor3d_Curve, NbPoints: int) -> None: ...
	@overload
	def __init__(self, C: Adaptor3d_Curve, NbPoints: int, U1: float, U2: float) -> None: ...
	@overload
	def __init__(self, C: Adaptor2d_Curve2d, NbPoints: int) -> None: ...
	@overload
	def __init__(self, C: Adaptor2d_Curve2d, NbPoints: int, U1: float, U2: float) -> None: ...
	@overload
	def Initialize(self, C: Adaptor3d_Curve, NbPoints: int) -> None: ...
	@overload
	def Initialize(self, C: Adaptor3d_Curve, NbPoints: int, U1: float, U2: float) -> None: ...
	@overload
	def Initialize(self, C: Adaptor2d_Curve2d, NbPoints: int) -> None: ...
	@overload
	def Initialize(self, C: Adaptor2d_Curve2d, NbPoints: int, U1: float, U2: float) -> None: ...
	def IsDone(self) -> bool: ...
	def NbPoints(self) -> int: ...
	def Parameter(self, Index: int) -> float: ...

class GCPnts_QuasiUniformDeflection:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, C: Adaptor3d_Curve, Deflection: float, Continuity: Optional[GeomAbs_Shape] = GeomAbs_C1) -> None: ...
	@overload
	def __init__(self, C: Adaptor2d_Curve2d, Deflection: float, Continuity: Optional[GeomAbs_Shape] = GeomAbs_C1) -> None: ...
	@overload
	def __init__(self, C: Adaptor3d_Curve, Deflection: float, U1: float, U2: float, Continuity: Optional[GeomAbs_Shape] = GeomAbs_C1) -> None: ...
	@overload
	def __init__(self, C: Adaptor2d_Curve2d, Deflection: float, U1: float, U2: float, Continuity: Optional[GeomAbs_Shape] = GeomAbs_C1) -> None: ...
	def Deflection(self) -> float: ...
	@overload
	def Initialize(self, C: Adaptor3d_Curve, Deflection: float, Continuity: Optional[GeomAbs_Shape] = GeomAbs_C1) -> None: ...
	@overload
	def Initialize(self, C: Adaptor2d_Curve2d, Deflection: float, Continuity: Optional[GeomAbs_Shape] = GeomAbs_C1) -> None: ...
	@overload
	def Initialize(self, C: Adaptor3d_Curve, Deflection: float, U1: float, U2: float, Continuity: Optional[GeomAbs_Shape] = GeomAbs_C1) -> None: ...
	@overload
	def Initialize(self, C: Adaptor2d_Curve2d, Deflection: float, U1: float, U2: float, Continuity: Optional[GeomAbs_Shape] = GeomAbs_C1) -> None: ...
	def IsDone(self) -> bool: ...
	def NbPoints(self) -> int: ...
	def Parameter(self, Index: int) -> float: ...
	def Value(self, Index: int) -> gp_Pnt: ...

class GCPnts_TangentialDeflection:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, C: Adaptor3d_Curve, AngularDeflection: float, CurvatureDeflection: float, MinimumOfPoints: Optional[int] = 2, UTol: Optional[float] = 1.0e-9, theMinLen: Optional[float] = 1.0e-7) -> None: ...
	@overload
	def __init__(self, C: Adaptor3d_Curve, FirstParameter: float, LastParameter: float, AngularDeflection: float, CurvatureDeflection: float, MinimumOfPoints: Optional[int] = 2, UTol: Optional[float] = 1.0e-9, theMinLen: Optional[float] = 1.0e-7) -> None: ...
	@overload
	def __init__(self, C: Adaptor2d_Curve2d, AngularDeflection: float, CurvatureDeflection: float, MinimumOfPoints: Optional[int] = 2, UTol: Optional[float] = 1.0e-9, theMinLen: Optional[float] = 1.0e-7) -> None: ...
	@overload
	def __init__(self, C: Adaptor2d_Curve2d, FirstParameter: float, LastParameter: float, AngularDeflection: float, CurvatureDeflection: float, MinimumOfPoints: Optional[int] = 2, UTol: Optional[float] = 1.0e-9, theMinLen: Optional[float] = 1.0e-7) -> None: ...
	def AddPoint(self, thePnt: gp_Pnt, theParam: float, theIsReplace: Optional[bool] = True) -> int: ...
	@staticmethod
	def ArcAngularStep(theRadius: float, theLinearDeflection: float, theAngularDeflection: float, theMinLength: float) -> float: ...
	@overload
	def Initialize(self, C: Adaptor3d_Curve, AngularDeflection: float, CurvatureDeflection: float, MinimumOfPoints: Optional[int] = 2, UTol: Optional[float] = 1.0e-9, theMinLen: Optional[float] = 1.0e-7) -> None: ...
	@overload
	def Initialize(self, C: Adaptor3d_Curve, FirstParameter: float, LastParameter: float, AngularDeflection: float, CurvatureDeflection: float, MinimumOfPoints: Optional[int] = 2, UTol: Optional[float] = 1.0e-9, theMinLen: Optional[float] = 1.0e-7) -> None: ...
	@overload
	def Initialize(self, C: Adaptor2d_Curve2d, AngularDeflection: float, CurvatureDeflection: float, MinimumOfPoints: Optional[int] = 2, UTol: Optional[float] = 1.0e-9, theMinLen: Optional[float] = 1.0e-7) -> None: ...
	@overload
	def Initialize(self, C: Adaptor2d_Curve2d, FirstParameter: float, LastParameter: float, AngularDeflection: float, CurvatureDeflection: float, MinimumOfPoints: Optional[int] = 2, UTol: Optional[float] = 1.0e-9, theMinLen: Optional[float] = 1.0e-7) -> None: ...
	def NbPoints(self) -> int: ...
	def Parameter(self, I: int) -> float: ...
	def Value(self, I: int) -> gp_Pnt: ...

class GCPnts_UniformAbscissa:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, C: Adaptor3d_Curve, Abscissa: float, Toler: Optional[float] = -1) -> None: ...
	@overload
	def __init__(self, C: Adaptor3d_Curve, Abscissa: float, U1: float, U2: float, Toler: Optional[float] = -1) -> None: ...
	@overload
	def __init__(self, C: Adaptor3d_Curve, NbPoints: int, Toler: Optional[float] = -1) -> None: ...
	@overload
	def __init__(self, C: Adaptor3d_Curve, NbPoints: int, U1: float, U2: float, Toler: Optional[float] = -1) -> None: ...
	@overload
	def __init__(self, C: Adaptor2d_Curve2d, Abscissa: float, Toler: Optional[float] = -1) -> None: ...
	@overload
	def __init__(self, C: Adaptor2d_Curve2d, Abscissa: float, U1: float, U2: float, Toler: Optional[float] = -1) -> None: ...
	@overload
	def __init__(self, C: Adaptor2d_Curve2d, NbPoints: int, Toler: Optional[float] = -1) -> None: ...
	@overload
	def __init__(self, C: Adaptor2d_Curve2d, NbPoints: int, U1: float, U2: float, Toler: Optional[float] = -1) -> None: ...
	def Abscissa(self) -> float: ...
	@overload
	def Initialize(self, C: Adaptor3d_Curve, Abscissa: float, Toler: Optional[float] = -1) -> None: ...
	@overload
	def Initialize(self, C: Adaptor3d_Curve, Abscissa: float, U1: float, U2: float, Toler: Optional[float] = -1) -> None: ...
	@overload
	def Initialize(self, C: Adaptor3d_Curve, NbPoints: int, Toler: Optional[float] = -1) -> None: ...
	@overload
	def Initialize(self, C: Adaptor3d_Curve, NbPoints: int, U1: float, U2: float, Toler: Optional[float] = -1) -> None: ...
	@overload
	def Initialize(self, C: Adaptor2d_Curve2d, Abscissa: float, Toler: Optional[float] = -1) -> None: ...
	@overload
	def Initialize(self, C: Adaptor2d_Curve2d, Abscissa: float, U1: float, U2: float, Toler: Optional[float] = -1) -> None: ...
	@overload
	def Initialize(self, C: Adaptor2d_Curve2d, NbPoints: int, Toler: Optional[float] = -1) -> None: ...
	@overload
	def Initialize(self, C: Adaptor2d_Curve2d, NbPoints: int, U1: float, U2: float, Toler: Optional[float] = -1) -> None: ...
	def IsDone(self) -> bool: ...
	def NbPoints(self) -> int: ...
	def Parameter(self, Index: int) -> float: ...

class GCPnts_UniformDeflection:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, C: Adaptor3d_Curve, Deflection: float, WithControl: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, C: Adaptor2d_Curve2d, Deflection: float, WithControl: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, C: Adaptor3d_Curve, Deflection: float, U1: float, U2: float, WithControl: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, C: Adaptor2d_Curve2d, Deflection: float, U1: float, U2: float, WithControl: Optional[bool] = True) -> None: ...
	def Deflection(self) -> float: ...
	@overload
	def Initialize(self, C: Adaptor3d_Curve, Deflection: float, WithControl: Optional[bool] = True) -> None: ...
	@overload
	def Initialize(self, C: Adaptor2d_Curve2d, Deflection: float, WithControl: Optional[bool] = True) -> None: ...
	@overload
	def Initialize(self, C: Adaptor3d_Curve, Deflection: float, U1: float, U2: float, WithControl: Optional[bool] = True) -> None: ...
	@overload
	def Initialize(self, C: Adaptor2d_Curve2d, Deflection: float, U1: float, U2: float, WithControl: Optional[bool] = True) -> None: ...
	def IsDone(self) -> bool: ...
	def NbPoints(self) -> int: ...
	def Parameter(self, Index: int) -> float: ...
	def Value(self, Index: int) -> gp_Pnt: ...

#classnotwrapped
class GCPnts_DistFunction: ...

#classnotwrapped
class GCPnts_DistFunction2d: ...

# harray1 classes
# harray2 classes
# hsequence classes

GCPnts_AbscissaPoint_Length = GCPnts_AbscissaPoint.Length
GCPnts_AbscissaPoint_Length = GCPnts_AbscissaPoint.Length
GCPnts_AbscissaPoint_Length = GCPnts_AbscissaPoint.Length
GCPnts_AbscissaPoint_Length = GCPnts_AbscissaPoint.Length
GCPnts_AbscissaPoint_Length = GCPnts_AbscissaPoint.Length
GCPnts_AbscissaPoint_Length = GCPnts_AbscissaPoint.Length
GCPnts_AbscissaPoint_Length = GCPnts_AbscissaPoint.Length
GCPnts_AbscissaPoint_Length = GCPnts_AbscissaPoint.Length
GCPnts_TangentialDeflection_ArcAngularStep = GCPnts_TangentialDeflection.ArcAngularStep



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
XBRepMesh module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_xbrepmesh.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _XBRepMesh
else:
    import _XBRepMesh

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _XBRepMesh.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _XBRepMesh.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _XBRepMesh.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _XBRepMesh.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _XBRepMesh.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _XBRepMesh.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _XBRepMesh.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _XBRepMesh.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _XBRepMesh.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _XBRepMesh.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _XBRepMesh.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _XBRepMesh.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _XBRepMesh.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _XBRepMesh.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _XBRepMesh.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _XBRepMesh.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _XBRepMesh.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _XBRepMesh:
_XBRepMesh.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _XBRepMesh.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.TopoDS
import OCC.Core.Message
import OCC.Core.TCollection
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.BRepMesh
import OCC.Core.IMeshTools
import OCC.Core.IMeshData
import OCC.Core.BRepAdaptor
import OCC.Core.Adaptor3d
import OCC.Core.Geom
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.Adaptor2d
import OCC.Core.Geom2d
import OCC.Core.math
import OCC.Core.GeomAdaptor
import OCC.Core.Geom2dAdaptor
import OCC.Core.Poly
import OCC.Core.TShort
import OCC.Core.Bnd
import OCC.Core.BVH

from enum import IntEnum
from OCC.Core.Exception import *



class xbrepmesh(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def Discret(*args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        theShape: TopoDS_Shape
        theDeflection: float
        theAngle: float
        theAlgo: BRepMesh_DiscretRoot *

        Returns
        -------
        int

        """
        return _XBRepMesh.xbrepmesh_Discret(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _XBRepMesh.xbrepmesh_swiginit(self, _XBRepMesh.new_xbrepmesh())
    __swig_destroy__ = _XBRepMesh.delete_xbrepmesh

# Register xbrepmesh in _XBRepMesh:
_XBRepMesh.xbrepmesh_swigregister(xbrepmesh)

def xbrepmesh_Discret(*args) -> "Standard_Integer":
    r"""
    No available documentation.

    Parameters
    ----------
    theShape: TopoDS_Shape
    theDeflection: float
    theAngle: float
    theAlgo: BRepMesh_DiscretRoot *

    Returns
    -------
    int

    """
    return _XBRepMesh.xbrepmesh_Discret(*args)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.gp import *


class GccEnt_Array1OfPosition:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> GccEnt_Position: ...
    def __setitem__(self, index: int, value: GccEnt_Position) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[GccEnt_Position]: ...
    def next(self) -> GccEnt_Position: ...
    __next__ = next
    def Init(self, theValue: GccEnt_Position) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> GccEnt_Position: ...
    def Last(self) -> GccEnt_Position: ...
    def Value(self, theIndex: int) -> GccEnt_Position: ...
    def SetValue(self, theIndex: int, theValue: GccEnt_Position) -> None: ...

class GccEnt_Position(IntEnum):
	GccEnt_unqualified: int = ...
	GccEnt_enclosing: int = ...
	GccEnt_enclosed: int = ...
	GccEnt_outside: int = ...
	GccEnt_noqualifier: int = ...
GccEnt_unqualified = GccEnt_Position.GccEnt_unqualified
GccEnt_enclosing = GccEnt_Position.GccEnt_enclosing
GccEnt_enclosed = GccEnt_Position.GccEnt_enclosed
GccEnt_outside = GccEnt_Position.GccEnt_outside
GccEnt_noqualifier = GccEnt_Position.GccEnt_noqualifier

class gccent:
	@overload
	@staticmethod
	def Enclosed(Obj: gp_Lin2d) -> GccEnt_QualifiedLin: ...
	@overload
	@staticmethod
	def Enclosed(Obj: gp_Circ2d) -> GccEnt_QualifiedCirc: ...
	@staticmethod
	def Enclosing(Obj: gp_Circ2d) -> GccEnt_QualifiedCirc: ...
	@overload
	@staticmethod
	def Outside(Obj: gp_Lin2d) -> GccEnt_QualifiedLin: ...
	@overload
	@staticmethod
	def Outside(Obj: gp_Circ2d) -> GccEnt_QualifiedCirc: ...
	@overload
	@staticmethod
	def PositionFromString(thePositionString: str) -> GccEnt_Position: ...
	@overload
	@staticmethod
	def PositionFromString(thePositionString: str, thePosition: GccEnt_Position) -> bool: ...
	@staticmethod
	def PositionToString(thePosition: GccEnt_Position) -> str: ...
	@overload
	@staticmethod
	def Unqualified(Obj: gp_Lin2d) -> GccEnt_QualifiedLin: ...
	@overload
	@staticmethod
	def Unqualified(Obj: gp_Circ2d) -> GccEnt_QualifiedCirc: ...

class GccEnt_QualifiedCirc:
	def __init__(self, Qualified: gp_Circ2d, Qualifier: GccEnt_Position) -> None: ...
	def IsEnclosed(self) -> bool: ...
	def IsEnclosing(self) -> bool: ...
	def IsOutside(self) -> bool: ...
	def IsUnqualified(self) -> bool: ...
	def Qualified(self) -> gp_Circ2d: ...
	def Qualifier(self) -> GccEnt_Position: ...

class GccEnt_QualifiedLin:
	def __init__(self, Qualified: gp_Lin2d, Qualifier: GccEnt_Position) -> None: ...
	def IsEnclosed(self) -> bool: ...
	def IsOutside(self) -> bool: ...
	def IsUnqualified(self) -> bool: ...
	def Qualified(self) -> gp_Lin2d: ...
	def Qualifier(self) -> GccEnt_Position: ...

# harray1 classes
# harray2 classes
# hsequence classes

gccent_Enclosed = gccent.Enclosed
gccent_Enclosed = gccent.Enclosed
gccent_Enclosing = gccent.Enclosing
gccent_Outside = gccent.Outside
gccent_Outside = gccent.Outside
gccent_PositionFromString = gccent.PositionFromString
gccent_PositionFromString = gccent.PositionFromString
gccent_PositionToString = gccent.PositionToString
gccent_Print = gccent.Print
gccent_Unqualified = gccent.Unqualified
gccent_Unqualified = gccent.Unqualified



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
Blend module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_blend.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _Blend
else:
    import _Blend

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _Blend.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _Blend.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _Blend.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _Blend.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _Blend.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _Blend.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _Blend.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _Blend.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _Blend.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _Blend.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _Blend.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _Blend.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _Blend.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _Blend.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _Blend.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _Blend.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _Blend.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _Blend:
_Blend.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _Blend.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.math
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.gp
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.Adaptor2d
import OCC.Core.Geom2d

from enum import IntEnum
from OCC.Core.Exception import *

Blend_StepTooLarge = _Blend.Blend_StepTooLarge
Blend_StepTooSmall = _Blend.Blend_StepTooSmall
Blend_Backward = _Blend.Blend_Backward
Blend_SamePoints = _Blend.Blend_SamePoints
Blend_OnRst1 = _Blend.Blend_OnRst1
Blend_OnRst2 = _Blend.Blend_OnRst2
Blend_OnRst12 = _Blend.Blend_OnRst12
Blend_OK = _Blend.Blend_OK
Blend_NoDecroch = _Blend.Blend_NoDecroch
Blend_DecrochRst1 = _Blend.Blend_DecrochRst1
Blend_DecrochRst2 = _Blend.Blend_DecrochRst2
Blend_DecrochBoth = _Blend.Blend_DecrochBoth


class Blend_Status(IntEnum):
	Blend_StepTooLarge = 0
	Blend_StepTooSmall = 1
	Blend_Backward = 2
	Blend_SamePoints = 3
	Blend_OnRst1 = 4
	Blend_OnRst2 = 5
	Blend_OnRst12 = 6
	Blend_OK = 7
Blend_StepTooLarge = Blend_Status.Blend_StepTooLarge
Blend_StepTooSmall = Blend_Status.Blend_StepTooSmall
Blend_Backward = Blend_Status.Blend_Backward
Blend_SamePoints = Blend_Status.Blend_SamePoints
Blend_OnRst1 = Blend_Status.Blend_OnRst1
Blend_OnRst2 = Blend_Status.Blend_OnRst2
Blend_OnRst12 = Blend_Status.Blend_OnRst12
Blend_OK = Blend_Status.Blend_OK

class Blend_DecrochStatus(IntEnum):
	Blend_NoDecroch = 0
	Blend_DecrochRst1 = 1
	Blend_DecrochRst2 = 2
	Blend_DecrochBoth = 3
Blend_NoDecroch = Blend_DecrochStatus.Blend_NoDecroch
Blend_DecrochRst1 = Blend_DecrochStatus.Blend_DecrochRst1
Blend_DecrochRst2 = Blend_DecrochStatus.Blend_DecrochRst2
Blend_DecrochBoth = Blend_DecrochStatus.Blend_DecrochBoth

class Blend_SequenceOfPoint(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< Blend_Point >::iterator":
        return _Blend.Blend_SequenceOfPoint_begin(self)

    def end(self) -> "NCollection_Sequence< Blend_Point >::iterator":
        return _Blend.Blend_SequenceOfPoint_end(self)

    def cbegin(self) -> "NCollection_Sequence< Blend_Point >::const_iterator":
        return _Blend.Blend_SequenceOfPoint_cbegin(self)

    def cend(self) -> "NCollection_Sequence< Blend_Point >::const_iterator":
        return _Blend.Blend_SequenceOfPoint_cend(self)

    def __init__(self, *args):
        _Blend.Blend_SequenceOfPoint_swiginit(self, _Blend.new_Blend_SequenceOfPoint(*args))

    def Size(self) -> "Standard_Integer":
        return _Blend.Blend_SequenceOfPoint_Size(self)

    def Length(self) -> "Standard_Integer":
        return _Blend.Blend_SequenceOfPoint_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _Blend.Blend_SequenceOfPoint_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _Blend.Blend_SequenceOfPoint_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _Blend.Blend_SequenceOfPoint_IsEmpty(self)

    def Reverse(self) -> "void":
        return _Blend.Blend_SequenceOfPoint_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _Blend.Blend_SequenceOfPoint_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _Blend.Blend_SequenceOfPoint_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _Blend.Blend_SequenceOfPoint_Clear(self, theAllocator)

    def Assign(self, theOther: "Blend_SequenceOfPoint") -> "NCollection_Sequence< Blend_Point > &":
        return _Blend.Blend_SequenceOfPoint_Assign(self, theOther)

    def Set(self, theOther: "Blend_SequenceOfPoint") -> "NCollection_Sequence< Blend_Point > &":
        return _Blend.Blend_SequenceOfPoint_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _Blend.Blend_SequenceOfPoint_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _Blend.Blend_SequenceOfPoint_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _Blend.Blend_SequenceOfPoint_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _Blend.Blend_SequenceOfPoint_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _Blend.Blend_SequenceOfPoint_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "Blend_SequenceOfPoint") -> "void":
        return _Blend.Blend_SequenceOfPoint_Split(self, theIndex, theSeq)

    def First(self) -> "Blend_Point const &":
        return _Blend.Blend_SequenceOfPoint_First(self)

    def ChangeFirst(self) -> "Blend_Point &":
        return _Blend.Blend_SequenceOfPoint_ChangeFirst(self)

    def Last(self) -> "Blend_Point const &":
        return _Blend.Blend_SequenceOfPoint_Last(self)

    def ChangeLast(self) -> "Blend_Point &":
        return _Blend.Blend_SequenceOfPoint_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "Blend_Point const &":
        return _Blend.Blend_SequenceOfPoint_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "Blend_Point &":
        return _Blend.Blend_SequenceOfPoint_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "Blend_Point &":
        return _Blend.Blend_SequenceOfPoint___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "Blend_Point") -> "void":
        return _Blend.Blend_SequenceOfPoint_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _Blend.delete_Blend_SequenceOfPoint

    def __len__(self):
        return self.Size()


# Register Blend_SequenceOfPoint in _Blend:
_Blend.Blend_SequenceOfPoint_swigregister(Blend_SequenceOfPoint)

def Blend_SequenceOfPoint_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _Blend.Blend_SequenceOfPoint_delNode(theNode, theAl)

class Blend_AppFunction(OCC.Core.math.math_FunctionSetWithDerivatives):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetBounds(self, *args) -> "void":
        r"""
        Returns in the vector infbound the lowest values allowed for each of the 4 variables. returns in the vector supbound the greatest values allowed for each of the 4 variables.

        Parameters
        ----------
        InfBound: math_Vector
        SupBound: math_Vector

        Returns
        -------
        None

        """
        return _Blend.Blend_AppFunction_GetBounds(self, *args)

    def GetMinimalDistance(self, *args) -> "Standard_Real":
        r"""
        Returns the minimal distance beetween two extremitys of calculed sections.

        Returns
        -------
        float

        """
        return _Blend.Blend_AppFunction_GetMinimalDistance(self, *args)

    def GetMinimalWeight(self, *args) -> "void":
        r"""
        Compute the minimal value of weight for each poles of all sections.

        Parameters
        ----------
        Weigths: TColStd_Array1OfReal

        Returns
        -------
        None

        """
        return _Blend.Blend_AppFunction_GetMinimalWeight(self, *args)

    def GetSectionSize(self, *args) -> "Standard_Real":
        r"""
        Returns the length of the maximum section.

        Returns
        -------
        float

        """
        return _Blend.Blend_AppFunction_GetSectionSize(self, *args)

    def GetShape(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------

        Returns
        -------
        NbPoles: int
        NbKnots: int
        Degree: int
        NbPoles2d: int

        """
        return _Blend.Blend_AppFunction_GetShape(self, *args)

    def GetTolerance(self, *args) -> "void":
        r"""
        Returns in the vector tolerance the parametric tolerance for each of the 4 variables; tol is the tolerance used in 3d space.

        Parameters
        ----------
        Tolerance: math_Vector
        Tol: float

        Returns
        -------
        None
        Returns the tolerance to reach in approximation to respecte boundtol error at the boundary angletol tangent error at the boundary surftol error inside the surface.

        Parameters
        ----------
        BoundTol: float
        SurfTol: float
        AngleTol: float
        Tol3d: math_Vector
        Tol1D: math_Vector

        Returns
        -------
        None

        """
        return _Blend.Blend_AppFunction_GetTolerance(self, *args)

    def Intervals(self, *args) -> "void":
        r"""
        Stores in <t> the parameters bounding the intervals of continuity <s>. //! the array must provide enough room to accomodate for the parameters. i.e. t.length() > nbintervals() raises outofrange from standard.

        Parameters
        ----------
        T: TColStd_Array1OfReal
        S: GeomAbs_Shape

        Returns
        -------
        None

        """
        return _Blend.Blend_AppFunction_Intervals(self, *args)

    def IsRational(self, *args) -> "Standard_Boolean":
        r"""
        Returns if the section is rationnal.

        Returns
        -------
        bool

        """
        return _Blend.Blend_AppFunction_IsRational(self, *args)

    def IsSolution(self, *args) -> "Standard_Boolean":
        r"""
        Returns standard_true if sol is a zero of the function. tol is the tolerance used in 3d space. the computation is made at the current value of the parameter on the guide line.

        Parameters
        ----------
        Sol: math_Vector
        Tol: float

        Returns
        -------
        bool

        """
        return _Blend.Blend_AppFunction_IsSolution(self, *args)

    def Knots(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        TKnots: TColStd_Array1OfReal

        Returns
        -------
        None

        """
        return _Blend.Blend_AppFunction_Knots(self, *args)

    def Mults(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        TMults: TColStd_Array1OfInteger

        Returns
        -------
        None

        """
        return _Blend.Blend_AppFunction_Mults(self, *args)

    def NbIntervals(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of intervals for continuity <s>. may be one if continuity(me) >= <s>.

        Parameters
        ----------
        S: GeomAbs_Shape

        Returns
        -------
        int

        """
        return _Blend.Blend_AppFunction_NbIntervals(self, *args)

    def Parameter(self, *args) -> "Standard_Real":
        r"""
        Returns the parameter of the point p. used to impose the parameters in the approximation.

        Parameters
        ----------
        P: Blend_Point

        Returns
        -------
        float

        """
        return _Blend.Blend_AppFunction_Parameter(self, *args)

    def Pnt1(self, *args) -> "gp_Pnt const":
        r"""
        Returns the point on the first support.

        Returns
        -------
        gp_Pnt

        """
        return _Blend.Blend_AppFunction_Pnt1(self, *args)

    def Pnt2(self, *args) -> "gp_Pnt const":
        r"""
        Returns the point on the first support.

        Returns
        -------
        gp_Pnt

        """
        return _Blend.Blend_AppFunction_Pnt2(self, *args)

    def Resolution(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        IC2d: int
        Tol: float

        Returns
        -------
        TolU: float
        TolV: float

        """
        return _Blend.Blend_AppFunction_Resolution(self, *args)

    def Section(self, *args) -> "Standard_Boolean":
        r"""
        Used for the first and last section the method returns standard_true if the derivatives are computed, otherwise it returns standard_false.

        Parameters
        ----------
        P: Blend_Point
        Poles: TColgp_Array1OfPnt
        DPoles: TColgp_Array1OfVec
        Poles2d: TColgp_Array1OfPnt2d
        DPoles2d: TColgp_Array1OfVec2d
        Weigths: TColStd_Array1OfReal
        DWeigths: TColStd_Array1OfReal

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        P: Blend_Point
        Poles: TColgp_Array1OfPnt
        Poles2d: TColgp_Array1OfPnt2d
        Weigths: TColStd_Array1OfReal

        Returns
        -------
        None
        Used for the first and last section the method returns standard_true if the derivatives are computed, otherwise it returns standard_false.

        Parameters
        ----------
        P: Blend_Point
        Poles: TColgp_Array1OfPnt
        DPoles: TColgp_Array1OfVec
        D2Poles: TColgp_Array1OfVec
        Poles2d: TColgp_Array1OfPnt2d
        DPoles2d: TColgp_Array1OfVec2d
        D2Poles2d: TColgp_Array1OfVec2d
        Weigths: TColStd_Array1OfReal
        DWeigths: TColStd_Array1OfReal
        D2Weigths: TColStd_Array1OfReal

        Returns
        -------
        bool

        """
        return _Blend.Blend_AppFunction_Section(self, *args)

    def Set(self, *args) -> "void":
        r"""
        Sets the value of the parameter along the guide line. this determines the plane in which the solution has to be found.

        Parameters
        ----------
        Param: float

        Returns
        -------
        None
        Sets the bounds of the parametric interval on the guide line. this determines the derivatives in these values if the function is not cn.

        Parameters
        ----------
        First: float
        Last: float

        Returns
        -------
        None

        """
        return _Blend.Blend_AppFunction_Set(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Blend.delete_Blend_AppFunction

# Register Blend_AppFunction in _Blend:
_Blend.Blend_AppFunction_swigregister(Blend_AppFunction)

class Blend_CurvPointFuncInv(OCC.Core.math.math_FunctionSetWithDerivatives):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetBounds(self, *args) -> "void":
        r"""
        Returns in the vector infbound the lowest values allowed for each of the 3 variables. returns in the vector supbound the greatest values allowed for each of the 3 variables.

        Parameters
        ----------
        InfBound: math_Vector
        SupBound: math_Vector

        Returns
        -------
        None

        """
        return _Blend.Blend_CurvPointFuncInv_GetBounds(self, *args)

    def GetTolerance(self, *args) -> "void":
        r"""
        Returns in the vector tolerance the parametric tolerance for each of the 3 variables; tol is the tolerance used in 3d space.

        Parameters
        ----------
        Tolerance: math_Vector
        Tol: float

        Returns
        -------
        None

        """
        return _Blend.Blend_CurvPointFuncInv_GetTolerance(self, *args)

    def IsSolution(self, *args) -> "Standard_Boolean":
        r"""
        Returns standard_true if sol is a zero of the function. tol is the tolerance used in 3d space.

        Parameters
        ----------
        Sol: math_Vector
        Tol: float

        Returns
        -------
        bool

        """
        return _Blend.Blend_CurvPointFuncInv_IsSolution(self, *args)

    def Set(self, *args) -> "void":
        r"""
        Set the point on which a solution has to be found.

        Parameters
        ----------
        P: gp_Pnt

        Returns
        -------
        None

        """
        return _Blend.Blend_CurvPointFuncInv_Set(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Blend.delete_Blend_CurvPointFuncInv

# Register Blend_CurvPointFuncInv in _Blend:
_Blend.Blend_CurvPointFuncInv_swigregister(Blend_CurvPointFuncInv)

class Blend_FuncInv(OCC.Core.math.math_FunctionSetWithDerivatives):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetBounds(self, *args) -> "void":
        r"""
        Returns in the vector infbound the lowest values allowed for each of the 4 variables. returns in the vector supbound the greatest values allowed for each of the 4 variables.

        Parameters
        ----------
        InfBound: math_Vector
        SupBound: math_Vector

        Returns
        -------
        None

        """
        return _Blend.Blend_FuncInv_GetBounds(self, *args)

    def GetTolerance(self, *args) -> "void":
        r"""
        Returns in the vector tolerance the parametric tolerance for each of the 4 variables; tol is the tolerance used in 3d space.

        Parameters
        ----------
        Tolerance: math_Vector
        Tol: float

        Returns
        -------
        None

        """
        return _Blend.Blend_FuncInv_GetTolerance(self, *args)

    def IsSolution(self, *args) -> "Standard_Boolean":
        r"""
        Returns standard_true if sol is a zero of the function. tol is the tolerance used in 3d space.

        Parameters
        ----------
        Sol: math_Vector
        Tol: float

        Returns
        -------
        bool

        """
        return _Blend.Blend_FuncInv_IsSolution(self, *args)

    def Set(self, *args) -> "void":
        r"""
        Sets the curveonsurface on which a solution has to be found. if <onfirst> is set to standard_true, the curve will be on the first surface, otherwise the curve is on the second one.

        Parameters
        ----------
        OnFirst: bool
        COnSurf: Adaptor2d_HCurve2d

        Returns
        -------
        None

        """
        return _Blend.Blend_FuncInv_Set(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Blend.delete_Blend_FuncInv

# Register Blend_FuncInv in _Blend:
_Blend.Blend_FuncInv_swigregister(Blend_FuncInv)

class Blend_Point(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        Creates a point on 2 surfaces, with tangents.

        Parameters
        ----------
        Pt1: gp_Pnt
        Pt2: gp_Pnt
        Param: float
        U1: float
        V1: float
        U2: float
        V2: float
        Tg1: gp_Vec
        Tg2: gp_Vec
        Tg12d: gp_Vec2d
        Tg22d: gp_Vec2d

        Returns
        -------
        None
        Creates a point on 2 surfaces, without tangents.

        Parameters
        ----------
        Pt1: gp_Pnt
        Pt2: gp_Pnt
        Param: float
        U1: float
        V1: float
        U2: float
        V2: float

        Returns
        -------
        None
        Creates a point on a surface and a curve, with tangents.

        Parameters
        ----------
        Pts: gp_Pnt
        Ptc: gp_Pnt
        Param: float
        U: float
        V: float
        W: float
        Tgs: gp_Vec
        Tgc: gp_Vec
        Tg2d: gp_Vec2d

        Returns
        -------
        None
        Creates a point on a surface and a curve, without tangents.

        Parameters
        ----------
        Pts: gp_Pnt
        Ptc: gp_Pnt
        Param: float
        U: float
        V: float
        W: float

        Returns
        -------
        None
        Creates a point on a surface and a curve on surface, with tangents.

        Parameters
        ----------
        Pt1: gp_Pnt
        Pt2: gp_Pnt
        Param: float
        U1: float
        V1: float
        U2: float
        V2: float
        PC: float
        Tg1: gp_Vec
        Tg2: gp_Vec
        Tg12d: gp_Vec2d
        Tg22d: gp_Vec2d

        Returns
        -------
        None
        Creates a point on a surface and a curve on surface, without tangents.

        Parameters
        ----------
        Pt1: gp_Pnt
        Pt2: gp_Pnt
        Param: float
        U1: float
        V1: float
        U2: float
        V2: float
        PC: float

        Returns
        -------
        None
        Creates a point on two curves on surfaces, with tangents.

        Parameters
        ----------
        Pt1: gp_Pnt
        Pt2: gp_Pnt
        Param: float
        U1: float
        V1: float
        U2: float
        V2: float
        PC1: float
        PC2: float
        Tg1: gp_Vec
        Tg2: gp_Vec
        Tg12d: gp_Vec2d
        Tg22d: gp_Vec2d

        Returns
        -------
        None
        Creates a point on two curves on surfaces, with tangents.

        Parameters
        ----------
        Pt1: gp_Pnt
        Pt2: gp_Pnt
        Param: float
        U1: float
        V1: float
        U2: float
        V2: float
        PC1: float
        PC2: float

        Returns
        -------
        None

        """
        _Blend.Blend_Point_swiginit(self, _Blend.new_Blend_Point(*args))

    def IsTangencyPoint(self, *args) -> "Standard_Boolean":
        r"""
        Returns standard_true if it was not possible to compute the tangent vectors at pointons1 and/or pointons2.

        Returns
        -------
        bool

        """
        return _Blend.Blend_Point_IsTangencyPoint(self, *args)

    def Parameter(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _Blend.Blend_Point_Parameter(self, *args)

    def ParameterOnC(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _Blend.Blend_Point_ParameterOnC(self, *args)

    def ParameterOnC1(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _Blend.Blend_Point_ParameterOnC1(self, *args)

    def ParameterOnC2(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _Blend.Blend_Point_ParameterOnC2(self, *args)

    def ParametersOnS(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------

        Returns
        -------
        U: float
        V: float

        """
        return _Blend.Blend_Point_ParametersOnS(self, *args)

    def ParametersOnS1(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------

        Returns
        -------
        U: float
        V: float

        """
        return _Blend.Blend_Point_ParametersOnS1(self, *args)

    def ParametersOnS2(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------

        Returns
        -------
        U: float
        V: float

        """
        return _Blend.Blend_Point_ParametersOnS2(self, *args)

    def PointOnC(self, *args) -> "gp_Pnt const":
        r"""
        No available documentation.

        Returns
        -------
        gp_Pnt

        """
        return _Blend.Blend_Point_PointOnC(self, *args)

    def PointOnC1(self, *args) -> "gp_Pnt const":
        r"""
        No available documentation.

        Returns
        -------
        gp_Pnt

        """
        return _Blend.Blend_Point_PointOnC1(self, *args)

    def PointOnC2(self, *args) -> "gp_Pnt const":
        r"""
        No available documentation.

        Returns
        -------
        gp_Pnt

        """
        return _Blend.Blend_Point_PointOnC2(self, *args)

    def PointOnS(self, *args) -> "gp_Pnt const":
        r"""
        No available documentation.

        Returns
        -------
        gp_Pnt

        """
        return _Blend.Blend_Point_PointOnS(self, *args)

    def PointOnS1(self, *args) -> "gp_Pnt const":
        r"""
        No available documentation.

        Returns
        -------
        gp_Pnt

        """
        return _Blend.Blend_Point_PointOnS1(self, *args)

    def PointOnS2(self, *args) -> "gp_Pnt const":
        r"""
        No available documentation.

        Returns
        -------
        gp_Pnt

        """
        return _Blend.Blend_Point_PointOnS2(self, *args)

    def SetParameter(self, *args) -> "void":
        r"""
        Changes parameter on existing point.

        Parameters
        ----------
        Param: float

        Returns
        -------
        None

        """
        return _Blend.Blend_Point_SetParameter(self, *args)

    def SetValue(self, *args) -> "void":
        r"""
        Set the values for a point on 2 surfaces, with tangents.

        Parameters
        ----------
        Pt1: gp_Pnt
        Pt2: gp_Pnt
        Param: float
        U1: float
        V1: float
        U2: float
        V2: float
        Tg1: gp_Vec
        Tg2: gp_Vec
        Tg12d: gp_Vec2d
        Tg22d: gp_Vec2d

        Returns
        -------
        None
        Set the values for a point on 2 surfaces, without tangents.

        Parameters
        ----------
        Pt1: gp_Pnt
        Pt2: gp_Pnt
        Param: float
        U1: float
        V1: float
        U2: float
        V2: float

        Returns
        -------
        None
        Set the values for a point on a surface and a curve, with tangents.

        Parameters
        ----------
        Pts: gp_Pnt
        Ptc: gp_Pnt
        Param: float
        U: float
        V: float
        W: float
        Tgs: gp_Vec
        Tgc: gp_Vec
        Tg2d: gp_Vec2d

        Returns
        -------
        None
        Set the values for a point on a surface and a curve, without tangents.

        Parameters
        ----------
        Pts: gp_Pnt
        Ptc: gp_Pnt
        Param: float
        U: float
        V: float
        W: float

        Returns
        -------
        None
        Creates a point on a surface and a curve on surface, with tangents.

        Parameters
        ----------
        Pt1: gp_Pnt
        Pt2: gp_Pnt
        Param: float
        U1: float
        V1: float
        U2: float
        V2: float
        PC: float
        Tg1: gp_Vec
        Tg2: gp_Vec
        Tg12d: gp_Vec2d
        Tg22d: gp_Vec2d

        Returns
        -------
        None
        Creates a point on a surface and a curve on surface, without tangents.

        Parameters
        ----------
        Pt1: gp_Pnt
        Pt2: gp_Pnt
        Param: float
        U1: float
        V1: float
        U2: float
        V2: float
        PC: float

        Returns
        -------
        None
        Creates a point on two curves on surfaces, with tangents.

        Parameters
        ----------
        Pt1: gp_Pnt
        Pt2: gp_Pnt
        Param: float
        U1: float
        V1: float
        U2: float
        V2: float
        PC1: float
        PC2: float
        Tg1: gp_Vec
        Tg2: gp_Vec
        Tg12d: gp_Vec2d
        Tg22d: gp_Vec2d

        Returns
        -------
        None
        Creates a point on two curves on surfaces, without tangents.

        Parameters
        ----------
        Pt1: gp_Pnt
        Pt2: gp_Pnt
        Param: float
        U1: float
        V1: float
        U2: float
        V2: float
        PC1: float
        PC2: float

        Returns
        -------
        None
        Creates a point on two curves.

        Parameters
        ----------
        Pt1: gp_Pnt
        Pt2: gp_Pnt
        Param: float
        PC1: float
        PC2: float

        Returns
        -------
        None

        """
        return _Blend.Blend_Point_SetValue(self, *args)

    def Tangent2d(self, *args) -> "gp_Vec2d":
        r"""
        No available documentation.

        Returns
        -------
        gp_Vec2d

        """
        return _Blend.Blend_Point_Tangent2d(self, *args)

    def Tangent2dOnS1(self, *args) -> "gp_Vec2d":
        r"""
        No available documentation.

        Returns
        -------
        gp_Vec2d

        """
        return _Blend.Blend_Point_Tangent2dOnS1(self, *args)

    def Tangent2dOnS2(self, *args) -> "gp_Vec2d":
        r"""
        No available documentation.

        Returns
        -------
        gp_Vec2d

        """
        return _Blend.Blend_Point_Tangent2dOnS2(self, *args)

    def TangentOnC(self, *args) -> "gp_Vec const":
        r"""
        No available documentation.

        Returns
        -------
        gp_Vec

        """
        return _Blend.Blend_Point_TangentOnC(self, *args)

    def TangentOnC1(self, *args) -> "gp_Vec const":
        r"""
        No available documentation.

        Returns
        -------
        gp_Vec

        """
        return _Blend.Blend_Point_TangentOnC1(self, *args)

    def TangentOnC2(self, *args) -> "gp_Vec const":
        r"""
        No available documentation.

        Returns
        -------
        gp_Vec

        """
        return _Blend.Blend_Point_TangentOnC2(self, *args)

    def TangentOnS(self, *args) -> "gp_Vec const":
        r"""
        No available documentation.

        Returns
        -------
        gp_Vec

        """
        return _Blend.Blend_Point_TangentOnS(self, *args)

    def TangentOnS1(self, *args) -> "gp_Vec const":
        r"""
        No available documentation.

        Returns
        -------
        gp_Vec

        """
        return _Blend.Blend_Point_TangentOnS1(self, *args)

    def TangentOnS2(self, *args) -> "gp_Vec const":
        r"""
        No available documentation.

        Returns
        -------
        gp_Vec

        """
        return _Blend.Blend_Point_TangentOnS2(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Blend.delete_Blend_Point

# Register Blend_Point in _Blend:
_Blend.Blend_Point_swigregister(Blend_Point)

class Blend_SurfCurvFuncInv(OCC.Core.math.math_FunctionSetWithDerivatives):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetBounds(self, *args) -> "void":
        r"""
        Returns in the vector infbound the lowest values allowed for each of the 3 variables. returns in the vector supbound the greatest values allowed for each of the 3 variables.

        Parameters
        ----------
        InfBound: math_Vector
        SupBound: math_Vector

        Returns
        -------
        None

        """
        return _Blend.Blend_SurfCurvFuncInv_GetBounds(self, *args)

    def GetTolerance(self, *args) -> "void":
        r"""
        Returns in the vector tolerance the parametric tolerance for each of the 3 variables; tol is the tolerance used in 3d space.

        Parameters
        ----------
        Tolerance: math_Vector
        Tol: float

        Returns
        -------
        None

        """
        return _Blend.Blend_SurfCurvFuncInv_GetTolerance(self, *args)

    def IsSolution(self, *args) -> "Standard_Boolean":
        r"""
        Returns standard_true if sol is a zero of the function. tol is the tolerance used in 3d space.

        Parameters
        ----------
        Sol: math_Vector
        Tol: float

        Returns
        -------
        bool

        """
        return _Blend.Blend_SurfCurvFuncInv_IsSolution(self, *args)

    def Set(self, *args) -> "void":
        r"""
        Set the point on which a solution has to be found.

        Parameters
        ----------
        Rst: Adaptor2d_HCurve2d

        Returns
        -------
        None

        """
        return _Blend.Blend_SurfCurvFuncInv_Set(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Blend.delete_Blend_SurfCurvFuncInv

# Register Blend_SurfCurvFuncInv in _Blend:
_Blend.Blend_SurfCurvFuncInv_swigregister(Blend_SurfCurvFuncInv)

class Blend_SurfPointFuncInv(OCC.Core.math.math_FunctionSetWithDerivatives):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetBounds(self, *args) -> "void":
        r"""
        Returns in the vector infbound the lowest values allowed for each of the 3 variables. returns in the vector supbound the greatest values allowed for each of the 3 variables.

        Parameters
        ----------
        InfBound: math_Vector
        SupBound: math_Vector

        Returns
        -------
        None

        """
        return _Blend.Blend_SurfPointFuncInv_GetBounds(self, *args)

    def GetTolerance(self, *args) -> "void":
        r"""
        Returns in the vector tolerance the parametric tolerance for each of the 3 variables; tol is the tolerance used in 3d space.

        Parameters
        ----------
        Tolerance: math_Vector
        Tol: float

        Returns
        -------
        None

        """
        return _Blend.Blend_SurfPointFuncInv_GetTolerance(self, *args)

    def IsSolution(self, *args) -> "Standard_Boolean":
        r"""
        Returns standard_true if sol is a zero of the function. tol is the tolerance used in 3d space.

        Parameters
        ----------
        Sol: math_Vector
        Tol: float

        Returns
        -------
        bool

        """
        return _Blend.Blend_SurfPointFuncInv_IsSolution(self, *args)

    def Set(self, *args) -> "void":
        r"""
        Set the point on which a solution has to be found.

        Parameters
        ----------
        P: gp_Pnt

        Returns
        -------
        None

        """
        return _Blend.Blend_SurfPointFuncInv_Set(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Blend.delete_Blend_SurfPointFuncInv

# Register Blend_SurfPointFuncInv in _Blend:
_Blend.Blend_SurfPointFuncInv_swigregister(Blend_SurfPointFuncInv)

class Blend_CSFunction(Blend_AppFunction):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetTolerance(self, *args) -> "void":
        r"""
        Returns in the vector tolerance the parametric tolerance for each of the 3 variables; tol is the tolerance used in 3d space.

        Parameters
        ----------
        Tolerance: math_Vector
        Tol: float

        Returns
        -------
        None
        Returns the tolerance to reach in approximation to respecte boundtol error at the boundary angletol tangent error at the boundary surftol error inside the surface.

        Parameters
        ----------
        BoundTol: float
        SurfTol: float
        AngleTol: float
        Tol3d: math_Vector
        Tol1D: math_Vector

        Returns
        -------
        None

        """
        return _Blend.Blend_CSFunction_GetTolerance(self, *args)

    def IsTangencyPoint(self, *args) -> "Standard_Boolean":
        r"""
        Returns true when it is not possible to compute the tangent vectors at pointons and/or pointonc.

        Returns
        -------
        bool

        """
        return _Blend.Blend_CSFunction_IsTangencyPoint(self, *args)

    def ParameterOnC(self, *args) -> "Standard_Real":
        r"""
        Returns parameter of the point on the curve.

        Returns
        -------
        float

        """
        return _Blend.Blend_CSFunction_ParameterOnC(self, *args)

    def Pnt2d(self, *args) -> "gp_Pnt2d const":
        r"""
        Returns u,v coordinates of the point on the surface.

        Returns
        -------
        gp_Pnt2d

        """
        return _Blend.Blend_CSFunction_Pnt2d(self, *args)

    def PointOnC(self, *args) -> "gp_Pnt const":
        r"""
        Returns the point on the curve.

        Returns
        -------
        gp_Pnt

        """
        return _Blend.Blend_CSFunction_PointOnC(self, *args)

    def PointOnS(self, *args) -> "gp_Pnt const":
        r"""
        Returns the point on the surface.

        Returns
        -------
        gp_Pnt

        """
        return _Blend.Blend_CSFunction_PointOnS(self, *args)

    def Section(self, *args) -> "Standard_Boolean":
        r"""
        Used for the first and last section the method returns standard_true if the derivatives are computed, otherwise it returns standard_false.

        Parameters
        ----------
        P: Blend_Point
        Poles: TColgp_Array1OfPnt
        DPoles: TColgp_Array1OfVec
        Poles2d: TColgp_Array1OfPnt2d
        DPoles2d: TColgp_Array1OfVec2d
        Weigths: TColStd_Array1OfReal
        DWeigths: TColStd_Array1OfReal

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        P: Blend_Point
        Poles: TColgp_Array1OfPnt
        Poles2d: TColgp_Array1OfPnt2d
        Weigths: TColStd_Array1OfReal

        Returns
        -------
        None
        Used for the first and last section the method returns standard_true if the derivatives are computed, otherwise it returns standard_false.

        Parameters
        ----------
        P: Blend_Point
        Poles: TColgp_Array1OfPnt
        DPoles: TColgp_Array1OfVec
        D2Poles: TColgp_Array1OfVec
        Poles2d: TColgp_Array1OfPnt2d
        DPoles2d: TColgp_Array1OfVec2d
        D2Poles2d: TColgp_Array1OfVec2d
        Weigths: TColStd_Array1OfReal
        DWeigths: TColStd_Array1OfReal
        D2Weigths: TColStd_Array1OfReal

        Returns
        -------
        bool

        """
        return _Blend.Blend_CSFunction_Section(self, *args)

    def Set(self, *args) -> "void":
        r"""
        Sets the value of the parameter along the guide line. this determines the plane in which the solution has to be found.

        Parameters
        ----------
        Param: float

        Returns
        -------
        None
        Sets the bounds of the parametric interval on the guide line. this determines the derivatives in these values if the function is not cn.

        Parameters
        ----------
        First: float
        Last: float

        Returns
        -------
        None

        """
        return _Blend.Blend_CSFunction_Set(self, *args)

    def Tangent(self, *args) -> "void":
        r"""
        Returns the tangent vector at the section, at the beginning and the end of the section, and returns the normal (of the surfaces) at these points.

        Parameters
        ----------
        U: float
        V: float
        TgS: gp_Vec
        NormS: gp_Vec

        Returns
        -------
        None

        """
        return _Blend.Blend_CSFunction_Tangent(self, *args)

    def Tangent2d(self, *args) -> "gp_Vec2d const":
        r"""
        Returns the tangent vector at pointons, in the parametric space of the first surface.

        Returns
        -------
        gp_Vec2d

        """
        return _Blend.Blend_CSFunction_Tangent2d(self, *args)

    def TangentOnC(self, *args) -> "gp_Vec const":
        r"""
        Returns the tangent vector at pointonc, in 3d space.

        Returns
        -------
        gp_Vec

        """
        return _Blend.Blend_CSFunction_TangentOnC(self, *args)

    def TangentOnS(self, *args) -> "gp_Vec const":
        r"""
        Returns the tangent vector at pointons, in 3d space.

        Returns
        -------
        gp_Vec

        """
        return _Blend.Blend_CSFunction_TangentOnS(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Blend.delete_Blend_CSFunction

# Register Blend_CSFunction in _Blend:
_Blend.Blend_CSFunction_swigregister(Blend_CSFunction)

class Blend_Function(Blend_AppFunction):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def IsTangencyPoint(self, *args) -> "Standard_Boolean":
        r"""
        Returns true when it is not possible to compute the tangent vectors at pointons1 and/or pointons2.

        Returns
        -------
        bool

        """
        return _Blend.Blend_Function_IsTangencyPoint(self, *args)

    def PointOnS1(self, *args) -> "gp_Pnt const":
        r"""
        Returns the point on the first surface, at parameter sol(1),sol(2) (sol is the vector used in the call of issolution.

        Returns
        -------
        gp_Pnt

        """
        return _Blend.Blend_Function_PointOnS1(self, *args)

    def PointOnS2(self, *args) -> "gp_Pnt const":
        r"""
        Returns the point on the second surface, at parameter sol(3),sol(4) (sol is the vector used in the call of issolution.

        Returns
        -------
        gp_Pnt

        """
        return _Blend.Blend_Function_PointOnS2(self, *args)

    def Section(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        P: Blend_Point
        Poles: TColgp_Array1OfPnt
        Poles2d: TColgp_Array1OfPnt2d
        Weigths: TColStd_Array1OfReal

        Returns
        -------
        None
        Used for the first and last section the method returns standard_true if the derivatives are computed, otherwise it returns standard_false.

        Parameters
        ----------
        P: Blend_Point
        Poles: TColgp_Array1OfPnt
        DPoles: TColgp_Array1OfVec
        D2Poles: TColgp_Array1OfVec
        Poles2d: TColgp_Array1OfPnt2d
        DPoles2d: TColgp_Array1OfVec2d
        D2Poles2d: TColgp_Array1OfVec2d
        Weigths: TColStd_Array1OfReal
        DWeigths: TColStd_Array1OfReal
        D2Weigths: TColStd_Array1OfReal

        Returns
        -------
        bool

        """
        return _Blend.Blend_Function_Section(self, *args)

    def Tangent(self, *args) -> "void":
        r"""
        Returns the tangent vector at the section, at the beginning and the end of the section, and returns the normal (of the surfaces) at these points.

        Parameters
        ----------
        U1: float
        V1: float
        U2: float
        V2: float
        TgFirst: gp_Vec
        TgLast: gp_Vec
        NormFirst: gp_Vec
        NormLast: gp_Vec

        Returns
        -------
        None

        """
        return _Blend.Blend_Function_Tangent(self, *args)

    def Tangent2dOnS1(self, *args) -> "gp_Vec2d const":
        r"""
        Returns the tangent vector at pointons1, in the parametric space of the first surface.

        Returns
        -------
        gp_Vec2d

        """
        return _Blend.Blend_Function_Tangent2dOnS1(self, *args)

    def Tangent2dOnS2(self, *args) -> "gp_Vec2d const":
        r"""
        Returns the tangent vector at pointons2, in the parametric space of the second surface.

        Returns
        -------
        gp_Vec2d

        """
        return _Blend.Blend_Function_Tangent2dOnS2(self, *args)

    def TangentOnS1(self, *args) -> "gp_Vec const":
        r"""
        Returns the tangent vector at pointons1, in 3d space.

        Returns
        -------
        gp_Vec

        """
        return _Blend.Blend_Function_TangentOnS1(self, *args)

    def TangentOnS2(self, *args) -> "gp_Vec const":
        r"""
        Returns the tangent vector at pointons2, in 3d space.

        Returns
        -------
        gp_Vec

        """
        return _Blend.Blend_Function_TangentOnS2(self, *args)

    def TwistOnS1(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _Blend.Blend_Function_TwistOnS1(self, *args)

    def TwistOnS2(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _Blend.Blend_Function_TwistOnS2(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Blend.delete_Blend_Function

# Register Blend_Function in _Blend:
_Blend.Blend_Function_swigregister(Blend_Function)

class Blend_RstRstFunction(Blend_AppFunction):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def Decroch(self, *args) -> "Blend_DecrochStatus":
        r"""
        Enables to implement a criterion of decrochage specific to the function. warning: can be called without previous call of issolution but the values calculated can be senseless.

        Parameters
        ----------
        Sol: math_Vector
        NRst1: gp_Vec
        TgRst1: gp_Vec
        NRst2: gp_Vec
        TgRst2: gp_Vec

        Returns
        -------
        Blend_DecrochStatus

        """
        return _Blend.Blend_RstRstFunction_Decroch(self, *args)

    def GetTolerance(self, *args) -> "void":
        r"""
        Returns in the vector tolerance the parametric tolerance for each variable; tol is the tolerance used in 3d space.

        Parameters
        ----------
        Tolerance: math_Vector
        Tol: float

        Returns
        -------
        None
        Returns the tolerance to reach in approximation to respecte boundtol error at the boundary angletol tangent error at the boundary surftol error inside the surface.

        Parameters
        ----------
        BoundTol: float
        SurfTol: float
        AngleTol: float
        Tol3d: math_Vector
        Tol1D: math_Vector

        Returns
        -------
        None

        """
        return _Blend.Blend_RstRstFunction_GetTolerance(self, *args)

    def IsTangencyPoint(self, *args) -> "Standard_Boolean":
        r"""
        Returns true when it is not possible to compute the tangent vectors at pointons and/or pointonrst.

        Returns
        -------
        bool

        """
        return _Blend.Blend_RstRstFunction_IsTangencyPoint(self, *args)

    def ParameterOnRst1(self, *args) -> "Standard_Real":
        r"""
        Returns parameter of the point on the curve.

        Returns
        -------
        float

        """
        return _Blend.Blend_RstRstFunction_ParameterOnRst1(self, *args)

    def ParameterOnRst2(self, *args) -> "Standard_Real":
        r"""
        Returns parameter of the point on the curve.

        Returns
        -------
        float

        """
        return _Blend.Blend_RstRstFunction_ParameterOnRst2(self, *args)

    def Pnt2dOnRst1(self, *args) -> "gp_Pnt2d const":
        r"""
        Returns u,v coordinates of the point on the surface.

        Returns
        -------
        gp_Pnt2d

        """
        return _Blend.Blend_RstRstFunction_Pnt2dOnRst1(self, *args)

    def Pnt2dOnRst2(self, *args) -> "gp_Pnt2d const":
        r"""
        Returns u,v coordinates of the point on the curve on surface.

        Returns
        -------
        gp_Pnt2d

        """
        return _Blend.Blend_RstRstFunction_Pnt2dOnRst2(self, *args)

    def PointOnRst1(self, *args) -> "gp_Pnt const":
        r"""
        Returns the point on the surface.

        Returns
        -------
        gp_Pnt

        """
        return _Blend.Blend_RstRstFunction_PointOnRst1(self, *args)

    def PointOnRst2(self, *args) -> "gp_Pnt const":
        r"""
        Returns the point on the curve.

        Returns
        -------
        gp_Pnt

        """
        return _Blend.Blend_RstRstFunction_PointOnRst2(self, *args)

    def Section(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        P: Blend_Point
        Poles: TColgp_Array1OfPnt
        Poles2d: TColgp_Array1OfPnt2d
        Weigths: TColStd_Array1OfReal

        Returns
        -------
        None
        Used for the first and last section the method returns standard_true if the derivatives are computed, otherwise it returns standard_false.

        Parameters
        ----------
        P: Blend_Point
        Poles: TColgp_Array1OfPnt
        DPoles: TColgp_Array1OfVec
        Poles2d: TColgp_Array1OfPnt2d
        DPoles2d: TColgp_Array1OfVec2d
        Weigths: TColStd_Array1OfReal
        DWeigths: TColStd_Array1OfReal

        Returns
        -------
        bool
        Used for the first and last section the method returns standard_true if the derivatives are computed, otherwise it returns standard_false.

        Parameters
        ----------
        P: Blend_Point
        Poles: TColgp_Array1OfPnt
        DPoles: TColgp_Array1OfVec
        D2Poles: TColgp_Array1OfVec
        Poles2d: TColgp_Array1OfPnt2d
        DPoles2d: TColgp_Array1OfVec2d
        D2Poles2d: TColgp_Array1OfVec2d
        Weigths: TColStd_Array1OfReal
        DWeigths: TColStd_Array1OfReal
        D2Weigths: TColStd_Array1OfReal

        Returns
        -------
        bool

        """
        return _Blend.Blend_RstRstFunction_Section(self, *args)

    def Set(self, *args) -> "void":
        r"""
        Sets the value of the parameter along the guide line. this determines the plane in which the solution has to be found.

        Parameters
        ----------
        Param: float

        Returns
        -------
        None
        Sets the bounds of the parametric interval on the guide line. this determines the derivatives in these values if the function is not cn.

        Parameters
        ----------
        First: float
        Last: float

        Returns
        -------
        None

        """
        return _Blend.Blend_RstRstFunction_Set(self, *args)

    def Tangent2dOnRst1(self, *args) -> "gp_Vec2d const":
        r"""
        Returns the tangent vector at pointons, in the parametric space of the first surface.

        Returns
        -------
        gp_Vec2d

        """
        return _Blend.Blend_RstRstFunction_Tangent2dOnRst1(self, *args)

    def Tangent2dOnRst2(self, *args) -> "gp_Vec2d const":
        r"""
        Returns the tangent vector at pointonrst, in the parametric space of the second surface.

        Returns
        -------
        gp_Vec2d

        """
        return _Blend.Blend_RstRstFunction_Tangent2dOnRst2(self, *args)

    def TangentOnRst1(self, *args) -> "gp_Vec const":
        r"""
        Returns the tangent vector at pointons, in 3d space.

        Returns
        -------
        gp_Vec

        """
        return _Blend.Blend_RstRstFunction_TangentOnRst1(self, *args)

    def TangentOnRst2(self, *args) -> "gp_Vec const":
        r"""
        Returns the tangent vector at pointonc, in 3d space.

        Returns
        -------
        gp_Vec

        """
        return _Blend.Blend_RstRstFunction_TangentOnRst2(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Blend.delete_Blend_RstRstFunction

# Register Blend_RstRstFunction in _Blend:
_Blend.Blend_RstRstFunction_swigregister(Blend_RstRstFunction)

class Blend_SurfRstFunction(Blend_AppFunction):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def Decroch(self, *args) -> "Standard_Boolean":
        r"""
        Enables implementation of a criterion of decrochage specific to the function.

        Parameters
        ----------
        Sol: math_Vector
        NS: gp_Vec
        TgS: gp_Vec

        Returns
        -------
        bool

        """
        return _Blend.Blend_SurfRstFunction_Decroch(self, *args)

    def GetTolerance(self, *args) -> "void":
        r"""
        Returns in the vector tolerance the parametric tolerance for each variable; tol is the tolerance used in 3d space.

        Parameters
        ----------
        Tolerance: math_Vector
        Tol: float

        Returns
        -------
        None
        Returns the tolerance to reach in approximation to respecte boundtol error at the boundary angletol tangent error at the boundary surftol error inside the surface.

        Parameters
        ----------
        BoundTol: float
        SurfTol: float
        AngleTol: float
        Tol3d: math_Vector
        Tol1D: math_Vector

        Returns
        -------
        None

        """
        return _Blend.Blend_SurfRstFunction_GetTolerance(self, *args)

    def IsTangencyPoint(self, *args) -> "Standard_Boolean":
        r"""
        Returns true when it is not possible to compute the tangent vectors at pointons and/or pointonrst.

        Returns
        -------
        bool

        """
        return _Blend.Blend_SurfRstFunction_IsTangencyPoint(self, *args)

    def ParameterOnRst(self, *args) -> "Standard_Real":
        r"""
        Returns parameter of the point on the curve.

        Returns
        -------
        float

        """
        return _Blend.Blend_SurfRstFunction_ParameterOnRst(self, *args)

    def Pnt2dOnRst(self, *args) -> "gp_Pnt2d const":
        r"""
        Returns u,v coordinates of the point on the curve on surface.

        Returns
        -------
        gp_Pnt2d

        """
        return _Blend.Blend_SurfRstFunction_Pnt2dOnRst(self, *args)

    def Pnt2dOnS(self, *args) -> "gp_Pnt2d const":
        r"""
        Returns u,v coordinates of the point on the surface.

        Returns
        -------
        gp_Pnt2d

        """
        return _Blend.Blend_SurfRstFunction_Pnt2dOnS(self, *args)

    def PointOnRst(self, *args) -> "gp_Pnt const":
        r"""
        Returns the point on the curve.

        Returns
        -------
        gp_Pnt

        """
        return _Blend.Blend_SurfRstFunction_PointOnRst(self, *args)

    def PointOnS(self, *args) -> "gp_Pnt const":
        r"""
        Returns the point on the surface.

        Returns
        -------
        gp_Pnt

        """
        return _Blend.Blend_SurfRstFunction_PointOnS(self, *args)

    def Section(self, *args) -> "void":
        r"""
        Used for the first and last section the method returns standard_true if the derivatives are computed, otherwise it returns standard_false.

        Parameters
        ----------
        P: Blend_Point
        Poles: TColgp_Array1OfPnt
        DPoles: TColgp_Array1OfVec
        Poles2d: TColgp_Array1OfPnt2d
        DPoles2d: TColgp_Array1OfVec2d
        Weigths: TColStd_Array1OfReal
        DWeigths: TColStd_Array1OfReal

        Returns
        -------
        bool
        Used for the first and last section the method returns standard_true if the derivatives are computed, otherwise it returns standard_false.

        Parameters
        ----------
        P: Blend_Point
        Poles: TColgp_Array1OfPnt
        DPoles: TColgp_Array1OfVec
        D2Poles: TColgp_Array1OfVec
        Poles2d: TColgp_Array1OfPnt2d
        DPoles2d: TColgp_Array1OfVec2d
        D2Poles2d: TColgp_Array1OfVec2d
        Weigths: TColStd_Array1OfReal
        DWeigths: TColStd_Array1OfReal
        D2Weigths: TColStd_Array1OfReal

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        P: Blend_Point
        Poles: TColgp_Array1OfPnt
        Poles2d: TColgp_Array1OfPnt2d
        Weigths: TColStd_Array1OfReal

        Returns
        -------
        None

        """
        return _Blend.Blend_SurfRstFunction_Section(self, *args)

    def Set(self, *args) -> "void":
        r"""
        Sets the value of the parameter along the guide line. this determines the plane in which the solution has to be found.

        Parameters
        ----------
        Param: float

        Returns
        -------
        None
        Sets the bounds of the parametric interval on the guide line. this determines the derivatives in these values if the function is not cn.

        Parameters
        ----------
        First: float
        Last: float

        Returns
        -------
        None

        """
        return _Blend.Blend_SurfRstFunction_Set(self, *args)

    def Tangent2dOnRst(self, *args) -> "gp_Vec2d const":
        r"""
        Returns the tangent vector at pointonrst, in the parametric space of the second surface.

        Returns
        -------
        gp_Vec2d

        """
        return _Blend.Blend_SurfRstFunction_Tangent2dOnRst(self, *args)

    def Tangent2dOnS(self, *args) -> "gp_Vec2d const":
        r"""
        Returns the tangent vector at pointons, in the parametric space of the first surface.

        Returns
        -------
        gp_Vec2d

        """
        return _Blend.Blend_SurfRstFunction_Tangent2dOnS(self, *args)

    def TangentOnRst(self, *args) -> "gp_Vec const":
        r"""
        Returns the tangent vector at pointonc, in 3d space.

        Returns
        -------
        gp_Vec

        """
        return _Blend.Blend_SurfRstFunction_TangentOnRst(self, *args)

    def TangentOnS(self, *args) -> "gp_Vec const":
        r"""
        Returns the tangent vector at pointons, in 3d space.

        Returns
        -------
        gp_Vec

        """
        return _Blend.Blend_SurfRstFunction_TangentOnS(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Blend.delete_Blend_SurfRstFunction

# Register Blend_SurfRstFunction in _Blend:
_Blend.Blend_SurfRstFunction_swigregister(Blend_SurfRstFunction)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TDocStd import *


class AppStd_Application(TDocStd_Application):
	def ResourcesName(self) -> str: ...

# harray1 classes
# harray2 classes
# hsequence classes

